Repository Analysis

microsoft/onnxruntime

ONNX Runtime: cross-platform, high performance ML inferencing and training accelerator

8.4 Low AI signal View on GitHub

Analysis Overview

This report presents the forensic synthetic code analysis of microsoft/onnxruntime, a C++ project with 21,083 GitHub stars. SynthScan v2.0 examined 1,260,596 lines of code across 5488 source files, recording 7016 pattern matches distributed across 23 syntactic categories. The overall adjusted score of 8.4 places this repository in the Low AI signal band.

The scanner applied 160+ deterministic lexical heuristics, multi-line block detectors, abstract syntax tree depth profilers, and a cross-file Jaccard similarity matrix to construct a statistically normalised synthetic code estimate. All matches are individually weighted by severity coefficient and contextual multiplier before summation, and the resulting headline score is temporally discounted to account for the repository's development history relative to the commercial emergence of large language model coding tooling (November 2022 onward).

8.4
Adjusted Score
8.4
Raw Score
100%
Time Factor
2026-07-14
Last Push
21.1K
Stars
C++
Language
1.3M
Lines of Code
5.5K
Files
7.0K
Pattern Hits
2026-07-14
Scan Date
0.03
HC Hit Rate

What These Metrics Mean

Adjusted Score
Primary synthetic code indicator. Raw score normalised per 1,000 lines of code and multiplied by the temporal discount factor. This is the definitive comparative metric — use it to rank repositories by AI authorship density.
Raw Score
The unmodified sum of all severity-weighted, context-multiplied pattern match scores before temporal discounting. Reflects the absolute signal strength independent of when the repository was last active.
Time Factor
The temporal discount multiplier (0–100%) applied to the raw score. Repositories last updated before ChatGPT's launch (Nov 2022) receive a 5% factor. Full signal is only assigned to repositories active in the post-adoption era (Jan 2024+).
Pattern Hits
Total count of individual pattern matches across all files and categories. A high hit count with a low score may indicate a very large codebase with isolated AI snippets; a low count with a high score indicates dense, concentrated AI signatures.
HC Hit Rate
High+Critical pattern hits per file, averaged across the repository. This orthogonal signal catches repositories where a few files are densely packed with high-severity AI tells — a strong indicator even when the normalised score appears moderate due to codebase size.
Lines of Code / Files
Total lines and files analysed. The scanner examines 94 file extensions. These denominators are used to normalise the score, enabling fair comparison between repositories of vastly different sizes.

Score History

This chart maps the temporal evolution of the adjusted synthetic code score across successive scan runs. An upward trajectory indicates ongoing incorporation of AI-generated code or expanding LLM-assisted scaffolding; a stable or declining trajectory may reflect active human refactoring, code removal, or the adoption of stricter authorship policies. The dashed secondary line (right axis) independently tracks total raw pattern hit count, which can diverge from the normalised score when codebase size changes significantly between scans.

Severity Breakdown

Classifies detected patterns by their diagnostic confidence and structural impact. CRITICAL patterns (coefficient 10) represent definitive synthetic signatures — hallucinated imports, explicit LLM attribution metadata — virtually never produced by human authors. HIGH (5) indicates strong structural tells such as cross-file repetition or cross-linguistic idioms. MEDIUM (2) covers recognisable conversational padding and AI-specific vocabulary. LOW (1) captures subtle indicators like tautological comments and generic boilerplate that require density to carry independent signal.

CRITICAL 9HIGH 138MEDIUM 1506LOW 5363

Directory Score Breakdown

This horizontal bar chart decomposes the repository's raw synthetic code score by top-level directory, allowing you to pinpoint precisely which modules or components carry the highest AI authorship density. Directories with disproportionately high scores relative to their size warrant targeted manual review: concentrated AI signatures often trace back to mass-generated configuration layers, auto-ported test suites, LLM-scaffolded boilerplate classes, or entire subsystems authored under heavy copilot assistance. Use this view to prioritise your human code-review effort.

Pattern Findings

The scanner identified 7016 distinct pattern matches across 23 syntactic categories. Each entry below represents a discrete location in the source code where the engine recorded a statistically significant AI authorship indicator. Expand any category row to inspect the individual file paths, line numbers, code snippets, and the lexical context (CODE, COMMENT, or STRING) in which each match was detected.

Reading the findings table: The Severity column indicates the diagnostic confidence level (CRITICAL / HIGH / MEDIUM / LOW). The Context column identifies whether the match occurred inside executable code, an inline comment, or a string literal — comment-context matches receive a ×1.5 weight because LLMs systematically over-annotate. The ⚡ bolt icon marks clustered matches: three or more patterns within a 10-line window, each receiving an additional ×1.5 density multiplier as dense clusters constitute far stronger evidence of synthetic authorship than isolated hits.

Decorative Section Separators1121 hits · 3549 pts
SeverityFileLineSnippetContext
MEDIUMsetup.py1# ------------------------------------------------------------------------COMMENT
MEDIUMsetup.py4# ------------------------------------------------------------------------COMMENT
MEDIUMtools/ci_build/compile_triton.py1# -------------------------------------------------------------------------COMMENT
MEDIUMtools/ci_build/compile_triton.py4# --------------------------------------------------------------------------COMMENT
MEDIUMtools/ci_build/set-trigger-rules.py1# -------------------------------------------------------------------------COMMENT
MEDIUMtools/ci_build/set-trigger-rules.py4# --------------------------------------------------------------------------COMMENT
MEDIUMtools/ci_build/cuda_plugin_parity_report.py517# ============================================================================COMMENT
MEDIUMtools/ci_build/cuda_plugin_parity_report.py519# ============================================================================COMMENT
MEDIUMtools/ci_build/github/Doxyfile_csharp.cfg2179#---------------------------------------------------------------------------COMMENT
MEDIUMtools/ci_build/github/Doxyfile_csharp.cfg2181#---------------------------------------------------------------------------COMMENT
MEDIUMtools/ci_build/github/Doxyfile_csharp.cfg2191#---------------------------------------------------------------------------COMMENT
MEDIUMtools/ci_build/github/Doxyfile_csharp.cfg2193#---------------------------------------------------------------------------COMMENT
MEDIUMtools/ci_build/github/Doxyfile_csharp.cfg25#---------------------------------------------------------------------------COMMENT
MEDIUMtools/ci_build/github/Doxyfile_csharp.cfg27#---------------------------------------------------------------------------COMMENT
MEDIUMtools/ci_build/github/Doxyfile_csharp.cfg491#---------------------------------------------------------------------------COMMENT
MEDIUMtools/ci_build/github/Doxyfile_csharp.cfg493#---------------------------------------------------------------------------COMMENT
MEDIUMtools/ci_build/github/Doxyfile_csharp.cfg810#---------------------------------------------------------------------------COMMENT
MEDIUMtools/ci_build/github/Doxyfile_csharp.cfg812#---------------------------------------------------------------------------COMMENT
MEDIUMtools/ci_build/github/Doxyfile_csharp.cfg901#---------------------------------------------------------------------------COMMENT
MEDIUMtools/ci_build/github/Doxyfile_csharp.cfg903#---------------------------------------------------------------------------COMMENT
MEDIUMtools/ci_build/github/Doxyfile_csharp.cfg1067#---------------------------------------------------------------------------COMMENT
MEDIUMtools/ci_build/github/Doxyfile_csharp.cfg1069#---------------------------------------------------------------------------COMMENT
MEDIUMtools/ci_build/github/Doxyfile_csharp.cfg1193#---------------------------------------------------------------------------COMMENT
MEDIUMtools/ci_build/github/Doxyfile_csharp.cfg1195#---------------------------------------------------------------------------COMMENT
MEDIUMtools/ci_build/github/Doxyfile_csharp.cfg1212#---------------------------------------------------------------------------COMMENT
MEDIUMtools/ci_build/github/Doxyfile_csharp.cfg1214#---------------------------------------------------------------------------COMMENT
MEDIUMtools/ci_build/github/Doxyfile_csharp.cfg1843#---------------------------------------------------------------------------COMMENT
MEDIUMtools/ci_build/github/Doxyfile_csharp.cfg1845#---------------------------------------------------------------------------COMMENT
MEDIUMtools/ci_build/github/Doxyfile_csharp.cfg2027#---------------------------------------------------------------------------COMMENT
MEDIUMtools/ci_build/github/Doxyfile_csharp.cfg2029#---------------------------------------------------------------------------COMMENT
MEDIUMtools/ci_build/github/Doxyfile_csharp.cfg2083#---------------------------------------------------------------------------COMMENT
MEDIUMtools/ci_build/github/Doxyfile_csharp.cfg2085#---------------------------------------------------------------------------COMMENT
MEDIUMtools/ci_build/github/Doxyfile_csharp.cfg2127#---------------------------------------------------------------------------COMMENT
MEDIUMtools/ci_build/github/Doxyfile_csharp.cfg2129#---------------------------------------------------------------------------COMMENT
MEDIUMtools/ci_build/github/Doxyfile_csharp.cfg2161#---------------------------------------------------------------------------COMMENT
MEDIUMtools/ci_build/github/Doxyfile_csharp.cfg2163#---------------------------------------------------------------------------COMMENT
MEDIUMtools/ci_build/github/Doxyfile_csharp.cfg2229#---------------------------------------------------------------------------COMMENT
MEDIUMtools/ci_build/github/Doxyfile_csharp.cfg2231#---------------------------------------------------------------------------COMMENT
MEDIUMtools/ci_build/github/Doxyfile_csharp.cfg2308#---------------------------------------------------------------------------COMMENT
MEDIUMtools/ci_build/github/Doxyfile_csharp.cfg2310#---------------------------------------------------------------------------COMMENT
MEDIUMtools/ci_build/github/Doxyfile_csharp.cfg2354#---------------------------------------------------------------------------COMMENT
MEDIUMtools/ci_build/github/Doxyfile_csharp.cfg2356#---------------------------------------------------------------------------COMMENT
MEDIUMtools/python/sparsify_initializers.py1# -------------------------------------------------------------------------COMMENT
MEDIUMtools/python/sparsify_initializers.py4# --------------------------------------------------------------------------COMMENT
MEDIUMtools/python/wgsl_template/code_pattern.py16# ----------------------------------------------------------------------COMMENT
MEDIUMtools/python/wgsl_template/code_pattern.py18# ----------------------------------------------------------------------COMMENT
MEDIUMtools/python/wgsl_template/code_pattern.py49# ----------------------------------------------------------------------COMMENT
MEDIUMtools/python/wgsl_template/code_pattern.py51# ----------------------------------------------------------------------COMMENT
MEDIUMtools/python/wgsl_template/code_pattern.py67# ----------------------------------------------------------------------COMMENT
MEDIUMtools/python/wgsl_template/code_pattern.py69# ----------------------------------------------------------------------COMMENT
MEDIUMtools/python/wgsl_template/code_pattern.py94# ----------------------------------------------------------------------COMMENT
MEDIUMtools/python/wgsl_template/code_pattern.py96# ----------------------------------------------------------------------COMMENT
MEDIUMtools/python/wgsl_template/code_pattern.py208# ----------------------------------------------------------------------COMMENT
MEDIUMtools/python/wgsl_template/code_pattern.py210# ----------------------------------------------------------------------COMMENT
MEDIUMtools/python/wgsl_template/types.py73# ----------------------------------------------------------------------COMMENT
MEDIUMtools/python/wgsl_template/types.py75# ----------------------------------------------------------------------COMMENT
MEDIUMtools/python/wgsl_template/parser.py36# ----------------------------------------------------------------------COMMENT
MEDIUMtools/python/wgsl_template/parser.py38# ----------------------------------------------------------------------COMMENT
MEDIUMtools/python/wgsl_template/parser.py103# ----------------------------------------------------------------------COMMENT
MEDIUMtools/python/wgsl_template/parser.py105# ----------------------------------------------------------------------COMMENT
1061 more matches not shown…
Over-Commented Block2102 hits · 2002 pts
SeverityFileLineSnippetContext
LOWThirdPartyNotices.txt1721#COMMENT
LOWsetup.py741 build_suffix = environ.get("BUILD_BUILDNUMBER")COMMENT
LOW.lintrunner.toml1# Configuration for lintrunner https://github.com/suo/lintrunnerCOMMENT
LOWtools/ci_build/build.py1281 if var in os.environ:COMMENT
LOWtools/ci_build/github/Doxyfile_csharp.cfg1# Doxyfile 1.9.4COMMENT
LOWtools/ci_build/github/Doxyfile_csharp.cfg21# Use doxygen to compare the used configuration file with the templateCOMMENT
LOWtools/ci_build/github/Doxyfile_csharp.cfg41# double-quotes, unless you are using Doxywizard) that should identify theCOMMENT
LOWtools/ci_build/github/Doxyfile_csharp.cfg61# in the documentation. The maximum height of the logo should not exceed 55COMMENT
LOWtools/ci_build/github/Doxyfile_csharp.cfg81# The default value is: NO.COMMENT
LOWtools/ci_build/github/Doxyfile_csharp.cfg101COMMENT
LOWtools/ci_build/github/Doxyfile_csharp.cfg121# documentation (similar to Javadoc). Set to NO to disable this.COMMENT
LOWtools/ci_build/github/Doxyfile_csharp.cfg161ALWAYS_DETAILED_SEC = NOCOMMENT
LOWtools/ci_build/github/Doxyfile_csharp.cfg181# If left blank the directory from which doxygen is run is used as the path toCOMMENT
LOWtools/ci_build/github/Doxyfile_csharp.cfg201# support long names like on DOS, Mac, or CD-ROM.COMMENT
LOWtools/ci_build/github/Doxyfile_csharp.cfg221# The default value is: NO.COMMENT
LOWtools/ci_build/github/Doxyfile_csharp.cfg241# The default value is: NO.COMMENT
LOWtools/ci_build/github/Doxyfile_csharp.cfg261# of the file/class/namespace that contains it.COMMENT
LOWtools/ci_build/github/Doxyfile_csharp.cfg281# of an alias to insert a newline as if a physical newline was in the originalCOMMENT
LOWtools/ci_build/github/Doxyfile_csharp.cfg301# The default value is: NO.COMMENT
LOWtools/ci_build/github/Doxyfile_csharp.cfg321# The default value is: NO.COMMENT
LOWtools/ci_build/github/Doxyfile_csharp.cfg341# the files are not read by doxygen. When specifying no_extension you should addCOMMENT
LOWtools/ci_build/github/Doxyfile_csharp.cfg361# Note: This feature currently applies only to Markdown headings.COMMENT
LOWtools/ci_build/github/Doxyfile_csharp.cfg381# The default value is: NO.COMMENT
LOWtools/ci_build/github/Doxyfile_csharp.cfg401# doxygen to replace the get and set methods by a property in the documentation.COMMENT
LOWtools/ci_build/github/Doxyfile_csharp.cfg421COMMENT
LOWtools/ci_build/github/Doxyfile_csharp.cfg441COMMENT
LOWtools/ci_build/github/Doxyfile_csharp.cfg461# The default value is: NO.COMMENT
LOWtools/ci_build/github/Doxyfile_csharp.cfg481# than 0 to get more control over the balance between CPU load and processingCOMMENT
LOWtools/ci_build/github/Doxyfile_csharp.cfg521EXTRACT_PACKAGE = NOCOMMENT
LOWtools/ci_build/github/Doxyfile_csharp.cfg541# The default value is: NO.COMMENT
LOWtools/ci_build/github/Doxyfile_csharp.cfg561# If the HIDE_UNDOC_MEMBERS tag is set to YES, doxygen will hide allCOMMENT
LOWtools/ci_build/github/Doxyfile_csharp.cfg581COMMENT
LOWtools/ci_build/github/Doxyfile_csharp.cfg601# whose names only differ in casing), the option must be set to YES to properlyCOMMENT
LOWtools/ci_build/github/Doxyfile_csharp.cfg621# If the HIDE_COMPOUND_REFERENCE tag is set to NO (default) then doxygen willCOMMENT
LOWtools/ci_build/github/Doxyfile_csharp.cfg641# grouped member an include statement to the documentation, telling the readerCOMMENT
LOWtools/ci_build/github/Doxyfile_csharp.cfg661# name. If set to NO, the members will appear in declaration order.COMMENT
LOWtools/ci_build/github/Doxyfile_csharp.cfg681# detailed member documentation.COMMENT
LOWtools/ci_build/github/Doxyfile_csharp.cfg701SORT_BY_SCOPE_NAME = NOCOMMENT
LOWtools/ci_build/github/Doxyfile_csharp.cfg721# The default value is: YES.COMMENT
LOWtools/ci_build/github/Doxyfile_csharp.cfg741COMMENT
LOWtools/ci_build/github/Doxyfile_csharp.cfg761COMMENT
LOWtools/ci_build/github/Doxyfile_csharp.cfg781# by doxygen. Whatever the program writes to standard output is used as the fileCOMMENT
LOWtools/ci_build/github/Doxyfile_csharp.cfg801# the reference definitions. This must be a list of .bib files. The .bibCOMMENT
LOWtools/ci_build/github/Doxyfile_csharp.cfg821# The WARNINGS tag can be used to turn on/off the warning messages that areCOMMENT
LOWtools/ci_build/github/Doxyfile_csharp.cfg841# The default value is: YES.COMMENT
LOWtools/ci_build/github/Doxyfile_csharp.cfg861COMMENT
LOWtools/ci_build/github/Doxyfile_csharp.cfg881COMMENT
LOWtools/ci_build/github/Doxyfile_csharp.cfg901#---------------------------------------------------------------------------COMMENT
LOWtools/ci_build/github/Doxyfile_csharp.cfg921INPUT_ENCODING = UTF-8COMMENT
LOWtools/ci_build/github/Doxyfile_csharp.cfg941FILE_PATTERNS = *.csCOMMENT
LOWtools/ci_build/github/Doxyfile_csharp.cfg961# The default value is: NO.COMMENT
LOWtools/ci_build/github/Doxyfile_csharp.cfg981# exclude all test directories use the pattern */test/*COMMENT
LOWtools/ci_build/github/Doxyfile_csharp.cfg1001# The default value is: NO.COMMENT
LOWtools/ci_build/github/Doxyfile_csharp.cfg1021#COMMENT
LOWtools/ci_build/github/Doxyfile_csharp.cfg1041# properly processed by doxygen.COMMENT
LOWtools/ci_build/github/Doxyfile_csharp.cfg1061# is part of the input, its contents will be placed on the main pageCOMMENT
LOWtools/ci_build/github/Doxyfile_csharp.cfg1081# classes and enums directly into the documentation.COMMENT
LOWtools/ci_build/github/Doxyfile_csharp.cfg1101# The default value is: NO.COMMENT
LOWtools/ci_build/github/Doxyfile_csharp.cfg1121SOURCE_TOOLTIPS = YESCOMMENT
LOWtools/ci_build/github/Doxyfile_csharp.cfg1141# This tag requires that the tag SOURCE_BROWSER is set to YES.COMMENT
2042 more matches not shown…
Hyper-Verbose Identifiers1704 hits · 1650 pts
SeverityFileLineSnippetContext
LOWsetup.py188 def _rewrite_ld_preload_tensorrt(self, to_preload):CODE
LOWsetup.py201 def _rewrite_ld_preload_nv_tensorrt_rtx(self, to_preload):CODE
LOWsetup.py834def save_build_and_package_info(package_name, version_number, cuda_version, qnn_version):CODE
LOWtools/ci_build/build.py208def number_of_test_parallel_jobs(args):CODE
LOWtools/ci_build/build.py221def number_of_flash_nvcc_threads(args):CODE
LOWtools/ci_build/build.py229def generate_vcpkg_install_options(build_dir, args):CODE
LOWtools/ci_build/build.py1903def parse_cuda_version_from_json(cuda_home):CODE
LOWtools/ci_build/op_registration_utils.py19def map_ort_constant_to_domain(ort_constant_name: str, allow_unknown_constant: bool = True):CODE
LOWtools/ci_build/op_registration_utils.py53def get_kernel_registration_files(ort_root=None, include_cuda=False):CODE
LOWtools/ci_build/op_registration_utils.py240def process_kernel_registration_file(filename: str | pathlib.Path, registration_processor: RegistrationProcessor):CODE
LOWtools/ci_build/manage_java_artifacts.py56def create_zip_from_directory(zip_file_path: Path, source_dir: Path):CODE
LOWtools/ci_build/build_args.py41def _openvino_verify_device_type(device_read: str) -> str:CODE
LOWtools/ci_build/build_args.py99def _webgpu_verify_library_kind(library_kind: str) -> str:CODE
LOWtools/ci_build/build_args.py170def add_cmake_build_config_args(parser: argparse.ArgumentParser) -> None:CODE
LOWtools/ci_build/build_args.py255def add_general_profiling_args(parser: argparse.ArgumentParser) -> None:CODE
LOWtools/ci_build/build_args.py260def add_debugging_sanitizer_args(parser: argparse.ArgumentParser) -> None:CODE
LOWtools/ci_build/build_args.py432def add_windows_specific_args(parser: argparse.ArgumentParser) -> None:CODE
LOWtools/ci_build/build_args.py584def add_threadpool_callback_args(parser: argparse.ArgumentParser) -> None:CODE
LOWtools/ci_build/build_args.py641def add_execution_provider_args(parser: argparse.ArgumentParser) -> None:CODE
LOWtools/ci_build/reduce_op_kernels.py31def _adapt_filters_for_extended_minimal_build(CODE
LOWtools/ci_build/reduce_op_kernels.py86 def is_typed_registration_needed(self, domain: str, optype: str, type_registration_str: str):CODE
LOWtools/ci_build/reduce_op_kernels.py191def _get_op_reduction_file_path(ort_root: Path, build_dir: Path, original_path: Path):CODE
LOWtools/ci_build/reduce_op_kernels.py200def _generate_provider_registrations(CODE
LOWtools/ci_build/reduce_op_kernels.py234def _generate_type_control_overrides(ort_root: Path, build_dir: Path, cpp_lines: typing.Sequence[str]):CODE
LOW…ols/ci_build/upload_python_package_to_azure_storage.py15def parse_nightly_and_local_version_from_whl_name(blob_name):CODE
LOWtools/ci_build/cuda_plugin_parity_report.py212def _extract_wrapper_registrations(content, file_path):CODE
LOWtools/ci_build/cuda_plugin_parity_report.py257def extract_kernel_registrations(file_path):CODE
LOWtools/ci_build/test_compile_triton.py13def load_compile_triton_module():CODE
LOWtools/ci_build/test_compile_triton.py27 def test_convert_lib_to_obj_uses_subprocess_run(self):CODE
LOWtools/ci_build/test_compile_triton.py54 def test_archive_obj_files_uses_subprocess_run(self):CODE
LOWtools/ci_build/test_compile_triton.py77 def test_convert_lib_to_obj_surfaces_subprocess_errors(self):CODE
LOWtools/ci_build/test_compile_triton.py93 def test_archive_obj_files_surfaces_os_errors(self):CODE
LOWtools/ci_build/op_registration_validator.py80 def _validate_all_registrations(self) -> int:CODE
LOWtools/ci_build/op_registration_validator.py85 def registration_info_sort_key(r: RegistrationInfo):CODE
LOWtools/ci_build/op_registration_validator.py105 def _validate_registrations_for_domain_and_op(self, registrations: typing.Iterator[RegistrationInfo]) -> int:CODE
LOWtools/ci_build/op_registration_validator.py159 def _validate_last_registration(self, last_r: RegistrationInfo) -> bool:CODE
LOWtools/ci_build/op_registration_validator.py208 def validate_registration_file(file: str) -> bool:CODE
LOWtools/ci_build/github/apple/package_release_tasks.py44def _resolve_single_path_from_pattern(path_pattern: str) -> Path:CODE
LOWtools/ci_build/github/apple/build_apple_framework.py23def _filter_sysroot_arch_pairs(CODE
LOWtools/ci_build/github/apple/build_apple_framework.py53def _find_or_build_sysroot_arch_framework(CODE
LOWtools/ci_build/github/apple/build_apple_framework.py105def _write_sysroot_arch_framework_build_outputs_to_file(CODE
LOWtools/ci_build/github/apple/build_apple_framework.py131def _assemble_fat_framework_for_sysroot(CODE
LOWtools/ci_build/github/apple/build_apple_framework.py200def _merge_framework_info_files(files: list[pathlib.Path], output_file: pathlib.Path):CODE
LOW…ols/ci_build/github/apple/get_simulator_device_info.py38def get_simulator_device_info(CODE
LOW…ols/ci_build/github/apple/get_simulator_device_info.py119 def runtime_id_and_device_pair_key(runtime_id_and_device_pair):CODE
LOWtools/ci_build/github/apple/build_settings_utils.py13def parse_build_settings_file(build_settings_file: pathlib.Path) -> dict[str, typing.Any]:CODE
LOWtools/ci_build/github/apple/build_settings_utils.py28 def validate_str_to_str_list_dict(input: dict[str, list[str]]):CODE
LOWtools/ci_build/github/apple/package_assembly_utils.py38 def replace_template_variable(match):CODE
LOWtools/ci_build/github/apple/package_assembly_utils.py78def copy_repo_relative_to_dir(patterns: list[str], dest_dir: pathlib.Path):CODE
LOW…d/github/apple/objectivec/assemble_objc_pod_package.py104def assemble_objc_pod_package(staging_dir: pathlib.Path, pod_version: str, framework_info_file: pathlib.Path):CODE
LOW…d/github/apple/objectivec/assemble_objc_pod_package.py136 def path_patterns_as_variable_value(patterns: list[str]):CODE
LOWtools/ci_build/github/windows/jar_packaging.py80def archive_directory_contents(archive_path: Path, source_dir: Path, description: str):CODE
LOWtools/python/compile_contributors.py115def extract_authors_from_commit(commit_id):CODE
LOWtools/python/cherry_pick_utils.py69def get_pr_number_from_subject(subject):CODE
LOWtools/python/create_reduced_build_config.py14def _get_suffix_match_predicate(suffix: str):CODE
LOWtools/python/create_reduced_build_config.py21def _extract_ops_from_onnx_graph(graph, operators, domain_opset_map):CODE
LOWtools/python/create_reduced_build_config.py63def _extract_ops_from_onnx_model(model_files: typing.Iterable[pathlib.Path]):CODE
LOWtools/python/create_reduced_build_config.py76def create_config_from_onnx_models(model_files: typing.Iterable[pathlib.Path], output_file: pathlib.Path):CODE
LOWtools/python/upload_and_run_browserstack_tests.py32def browserstack_build_request(devices, app_url, test_suite_url, test_platform, id, token, project, build_tag):STRING
LOWtools/python/gen_contrib_doc.py84def display_function_version_link(name, version): # type: (Text, int) -> TextCODE
1644 more matches not shown…
Self-Referential Comments257 hits · 666 pts
SeverityFileLineSnippetContext
MEDIUMtools/ci_build/build.py572 # This file is for building the vcpkg ports.COMMENT
MEDIUMtools/ci_build/prepare_macos_package.py156 # Create a zip file in the staging directory.COMMENT
MEDIUM…azure-pipelines/stages/plugin-cuda-packaging-stage.yml340 # Create a version folder in the output artifact with a file whose name is the version string.COMMENT
MEDIUM…ure-pipelines/stages/set_packaging_variables_stage.yml59 # Create the file with the first parameterCOMMENT
MEDIUM…ure-pipelines/stages/plugin-webgpu-packaging-stage.yml231 # Create a version folder in the output artifact with a file whose name is the version string.COMMENT
MEDIUM…d/github/azure-pipelines/templates/c-api-linux-cpu.yml1# This file contains the ADO job that build libonnxruntime.so on LinuxCOMMENT
MEDIUM…hub/azure-pipelines/templates/android-java-api-aar.yml91 # Create a folder for artifactsCOMMENT
MEDIUM…lines/templates/set-plugin-ep-build-variables-step.yml1# This file is used to set variables for plugin build stages. It sets the package versionCOMMENT
MEDIUM…build/github/azure-pipelines/templates/setup-maven.yml9 # Define the scope for the access tokenCOMMENT
MEDIUM…b/azure-pipelines/templates/make_java_win_binaries.yml51 # Define the path to the python script within your repositoryCOMMENT
MEDIUMtools/python/update_version.py39 # Create a new row based on the separator, replacing dashes with spaces and adding the versionCOMMENT
MEDIUMtools/python/gen_contrib_doc.py3# This file is copied and adapted from https://github.com/onnx/onnx repository.COMMENT
MEDIUMtools/python/util/vcpkg_helpers.py578 # Define the path to the intermediate toolchain file used by vcpkg for wasmSTRING
MEDIUMtools/python/util/vcpkg_helpers.py625 cxxflags = list(base_flags) # Create a copySTRING
MEDIUMtools/python/util/convert_onnx_models_to_ort.py133 # Create an ONNX file with the same optimization level that will be used for the ORT format file.COMMENT
MEDIUMtools/python/util/test/test_onnx_model_utils.py58 # Create the main graphCOMMENT
MEDIUMtools/nuget/generate_nuspec_for_native_nuget.py1241 # Create the nuspec needed to generate the NugetCOMMENT
MEDIUMonnxruntime/core/flatbuffers/schema/compile_schema.py103 # Create a copy of the schema so we can replace the namespace so that the generated module name doesn'tCOMMENT
MEDIUM…rs/ort_flatbuffers_py/fbs/RuntimeOptimizationRecord.py23 """This method is deprecated. Please switch to GetRootAs."""STRING
MEDIUM…/ort_flatbuffers_py/fbs/DeprecatedKernelCreateInfos.py22 """This method is deprecated. Please switch to GetRootAs."""STRING
MEDIUM…ffers/ort_flatbuffers_py/fbs/NodesToOptimizeIndices.py23 """This method is deprecated. Please switch to GetRootAs."""STRING
MEDIUM…e/core/flatbuffers/ort_flatbuffers_py/fbs/Attribute.py21 """This method is deprecated. Please switch to GetRootAs."""STRING
MEDIUM…ore/flatbuffers/ort_flatbuffers_py/fbs/SequenceType.py21 """This method is deprecated. Please switch to GetRootAs."""STRING
MEDIUM…ffers/ort_flatbuffers_py/fbs/DeprecatedSessionState.py22 """This method is deprecated. Please switch to GetRootAs."""STRING
MEDIUM…flatbuffers/ort_flatbuffers_py/fbs/InferenceSession.py21 """This method is deprecated. Please switch to GetRootAs."""STRING
MEDIUM…/core/flatbuffers/ort_flatbuffers_py/fbs/Checkpoint.py21 """This method is deprecated. Please switch to GetRootAs."""STRING
MEDIUM…e/flatbuffers/ort_flatbuffers_py/fbs/OptimizerGroup.py21 """This method is deprecated. Please switch to GetRootAs."""STRING
MEDIUM…re/flatbuffers/ort_flatbuffers_py/fbs/OperatorSetId.py21 """This method is deprecated. Please switch to GetRootAs."""STRING
MEDIUM…core/flatbuffers/ort_flatbuffers_py/fbs/PropertyBag.py21 """This method is deprecated. Please switch to GetRootAs."""STRING
MEDIUM…e/core/flatbuffers/ort_flatbuffers_py/fbs/ValueInfo.py21 """This method is deprecated. Please switch to GetRootAs."""STRING
MEDIUM…buffers/ort_flatbuffers_py/fbs/RuntimeOptimizations.py21 """This method is deprecated. Please switch to GetRootAs."""STRING
MEDIUM…s/ort_flatbuffers_py/fbs/OpIdKernelTypeStrArgsEntry.py21 """This method is deprecated. Please switch to GetRootAs."""STRING
MEDIUM…ntime/core/flatbuffers/ort_flatbuffers_py/fbs/Graph.py21 """This method is deprecated. Please switch to GetRootAs."""STRING
MEDIUM…ime/core/flatbuffers/ort_flatbuffers_py/fbs/MapType.py21 """This method is deprecated. Please switch to GetRootAs."""STRING
MEDIUM…atbuffers/ort_flatbuffers_py/fbs/TensorTypeAndShape.py21 """This method is deprecated. Please switch to GetRootAs."""STRING
MEDIUM…fers/ort_flatbuffers_py/fbs/ParameterOptimizerState.py21 """This method is deprecated. Please switch to GetRootAs."""STRING
MEDIUM…ore/flatbuffers/ort_flatbuffers_py/fbs/SparseTensor.py21 """This method is deprecated. Please switch to GetRootAs."""STRING
MEDIUM…fers_py/fbs/RuntimeOptimizationRecordContainerEntry.py21 """This method is deprecated. Please switch to GetRootAs."""STRING
MEDIUM…e/flatbuffers/ort_flatbuffers_py/fbs/DimensionValue.py21 """This method is deprecated. Please switch to GetRootAs."""STRING
MEDIUM…me/core/flatbuffers/ort_flatbuffers_py/fbs/TypeInfo.py21 """This method is deprecated. Please switch to GetRootAs."""STRING
MEDIUM…uffers/ort_flatbuffers_py/fbs/KernelTypeStrResolver.py21 """This method is deprecated. Please switch to GetRootAs."""STRING
MEDIUM…ntime/core/flatbuffers/ort_flatbuffers_py/fbs/Model.py21 """This method is deprecated. Please switch to GetRootAs."""STRING
MEDIUM…time/core/flatbuffers/ort_flatbuffers_py/fbs/Tensor.py21 """This method is deprecated. Please switch to GetRootAs."""STRING
MEDIUM…t_flatbuffers_py/fbs/DeprecatedSubGraphSessionState.py22 """This method is deprecated. Please switch to GetRootAs."""STRING
MEDIUM…tbuffers_py/fbs/DeprecatedNodeIndexAndKernelDefHash.py22 """This method is deprecated. Please switch to GetRootAs."""STRING
MEDIUM…latbuffers/ort_flatbuffers_py/fbs/StringStringEntry.py21 """This method is deprecated. Please switch to GetRootAs."""STRING
MEDIUM…me/core/flatbuffers/ort_flatbuffers_py/fbs/NodeEdge.py21 """This method is deprecated. Please switch to GetRootAs."""STRING
MEDIUM…ntime/core/flatbuffers/ort_flatbuffers_py/fbs/Shape.py21 """This method is deprecated. Please switch to GetRootAs."""STRING
MEDIUM…e/flatbuffers/ort_flatbuffers_py/fbs/StringProperty.py21 """This method is deprecated. Please switch to GetRootAs."""STRING
MEDIUM…core/flatbuffers/ort_flatbuffers_py/fbs/ModuleState.py21 """This method is deprecated. Please switch to GetRootAs."""STRING
MEDIUM…untime/core/flatbuffers/ort_flatbuffers_py/fbs/Node.py21 """This method is deprecated. Please switch to GetRootAs."""STRING
MEDIUM…re/flatbuffers/ort_flatbuffers_py/fbs/FloatProperty.py21 """This method is deprecated. Please switch to GetRootAs."""STRING
MEDIUM…ffers/ort_flatbuffers_py/fbs/KernelTypeStrArgsEntry.py21 """This method is deprecated. Please switch to GetRootAs."""STRING
MEDIUM…/flatbuffers/ort_flatbuffers_py/fbs/ArgTypeAndIndex.py21 """This method is deprecated. Please switch to GetRootAs."""STRING
MEDIUM…core/flatbuffers/ort_flatbuffers_py/fbs/IntProperty.py21 """This method is deprecated. Please switch to GetRootAs."""STRING
MEDIUM…e/core/flatbuffers/ort_flatbuffers_py/fbs/Dimension.py21 """This method is deprecated. Please switch to GetRootAs."""STRING
MEDIUMonnxruntime/test/testdata/icm-31000000518483.py20# Create the main graphCOMMENT
MEDIUMonnxruntime/test/testdata/ort_github_issue_10305.py22# Create the main graphCOMMENT
MEDIUM…xruntime/test/testdata/test_arbitrary_external_file.py46 # Create the modelCOMMENT
MEDIUMonnxruntime/test/testdata/ort_github_issue_26272.py4# Create a simple ONNX model with DDS outputCOMMENT
197 more matches not shown…
Cross-File Repetition104 hits · 520 pts
SeverityFileLineSnippetContext
HIGH…rs/ort_flatbuffers_py/fbs/RuntimeOptimizationRecord.py0this method is deprecated. please switch to getrootas.STRING
HIGH…/ort_flatbuffers_py/fbs/DeprecatedKernelCreateInfos.py0this method is deprecated. please switch to getrootas.STRING
HIGH…ffers/ort_flatbuffers_py/fbs/NodesToOptimizeIndices.py0this method is deprecated. please switch to getrootas.STRING
HIGH…e/core/flatbuffers/ort_flatbuffers_py/fbs/Attribute.py0this method is deprecated. please switch to getrootas.STRING
HIGH…ore/flatbuffers/ort_flatbuffers_py/fbs/SequenceType.py0this method is deprecated. please switch to getrootas.STRING
HIGH…ffers/ort_flatbuffers_py/fbs/DeprecatedSessionState.py0this method is deprecated. please switch to getrootas.STRING
HIGH…flatbuffers/ort_flatbuffers_py/fbs/InferenceSession.py0this method is deprecated. please switch to getrootas.STRING
HIGH…/core/flatbuffers/ort_flatbuffers_py/fbs/Checkpoint.py0this method is deprecated. please switch to getrootas.STRING
HIGH…e/flatbuffers/ort_flatbuffers_py/fbs/OptimizerGroup.py0this method is deprecated. please switch to getrootas.STRING
HIGH…re/flatbuffers/ort_flatbuffers_py/fbs/OperatorSetId.py0this method is deprecated. please switch to getrootas.STRING
HIGH…core/flatbuffers/ort_flatbuffers_py/fbs/PropertyBag.py0this method is deprecated. please switch to getrootas.STRING
HIGH…e/core/flatbuffers/ort_flatbuffers_py/fbs/ValueInfo.py0this method is deprecated. please switch to getrootas.STRING
HIGH…buffers/ort_flatbuffers_py/fbs/RuntimeOptimizations.py0this method is deprecated. please switch to getrootas.STRING
HIGH…s/ort_flatbuffers_py/fbs/OpIdKernelTypeStrArgsEntry.py0this method is deprecated. please switch to getrootas.STRING
HIGH…ntime/core/flatbuffers/ort_flatbuffers_py/fbs/Graph.py0this method is deprecated. please switch to getrootas.STRING
HIGH…ime/core/flatbuffers/ort_flatbuffers_py/fbs/MapType.py0this method is deprecated. please switch to getrootas.STRING
HIGH…atbuffers/ort_flatbuffers_py/fbs/TensorTypeAndShape.py0this method is deprecated. please switch to getrootas.STRING
HIGH…fers/ort_flatbuffers_py/fbs/ParameterOptimizerState.py0this method is deprecated. please switch to getrootas.STRING
HIGH…ore/flatbuffers/ort_flatbuffers_py/fbs/SparseTensor.py0this method is deprecated. please switch to getrootas.STRING
HIGH…fers_py/fbs/RuntimeOptimizationRecordContainerEntry.py0this method is deprecated. please switch to getrootas.STRING
HIGH…e/flatbuffers/ort_flatbuffers_py/fbs/DimensionValue.py0this method is deprecated. please switch to getrootas.STRING
HIGH…me/core/flatbuffers/ort_flatbuffers_py/fbs/TypeInfo.py0this method is deprecated. please switch to getrootas.STRING
HIGH…uffers/ort_flatbuffers_py/fbs/KernelTypeStrResolver.py0this method is deprecated. please switch to getrootas.STRING
HIGH…ntime/core/flatbuffers/ort_flatbuffers_py/fbs/Model.py0this method is deprecated. please switch to getrootas.STRING
HIGH…time/core/flatbuffers/ort_flatbuffers_py/fbs/Tensor.py0this method is deprecated. please switch to getrootas.STRING
HIGH…t_flatbuffers_py/fbs/DeprecatedSubGraphSessionState.py0this method is deprecated. please switch to getrootas.STRING
HIGH…tbuffers_py/fbs/DeprecatedNodeIndexAndKernelDefHash.py0this method is deprecated. please switch to getrootas.STRING
HIGH…latbuffers/ort_flatbuffers_py/fbs/StringStringEntry.py0this method is deprecated. please switch to getrootas.STRING
HIGH…me/core/flatbuffers/ort_flatbuffers_py/fbs/NodeEdge.py0this method is deprecated. please switch to getrootas.STRING
HIGH…ntime/core/flatbuffers/ort_flatbuffers_py/fbs/Shape.py0this method is deprecated. please switch to getrootas.STRING
HIGH…e/flatbuffers/ort_flatbuffers_py/fbs/StringProperty.py0this method is deprecated. please switch to getrootas.STRING
HIGH…core/flatbuffers/ort_flatbuffers_py/fbs/ModuleState.py0this method is deprecated. please switch to getrootas.STRING
HIGH…untime/core/flatbuffers/ort_flatbuffers_py/fbs/Node.py0this method is deprecated. please switch to getrootas.STRING
HIGH…re/flatbuffers/ort_flatbuffers_py/fbs/FloatProperty.py0this method is deprecated. please switch to getrootas.STRING
HIGH…ffers/ort_flatbuffers_py/fbs/KernelTypeStrArgsEntry.py0this method is deprecated. please switch to getrootas.STRING
HIGH…/flatbuffers/ort_flatbuffers_py/fbs/ArgTypeAndIndex.py0this method is deprecated. please switch to getrootas.STRING
HIGH…core/flatbuffers/ort_flatbuffers_py/fbs/IntProperty.py0this method is deprecated. please switch to getrootas.STRING
HIGH…e/core/flatbuffers/ort_flatbuffers_py/fbs/Dimension.py0this method is deprecated. please switch to getrootas.STRING
HIGH…hon/tools/quantization/CalTableFlatBuffers/TrtTable.py0this method is deprecated. please switch to getrootas.STRING
HIGH…hon/tools/quantization/CalTableFlatBuffers/KeyValue.py0this method is deprecated. please switch to getrootas.STRING
HIGHonnxruntime/test/testdata/packed_attention_fp16.rbp.py0run this script to recreate the original onnx model. example usage: python matmulnbits_add_gen.py out_model_path.onnxSTRING
HIGHonnxruntime/test/testdata/abs_0d_lostdim.py0run this script to recreate the original onnx model. example usage: python matmulnbits_add_gen.py out_model_path.onnxSTRING
HIGHonnxruntime/test/testdata/abs_0d_input.py0run this script to recreate the original onnx model. example usage: python matmulnbits_add_gen.py out_model_path.onnxSTRING
HIGH…/transform/runtime_optimization/matmulnbits_add_gen.py0run this script to recreate the original onnx model. example usage: python matmulnbits_add_gen.py out_model_path.onnxSTRING
HIGH…ation/lr_scheduler/lr_scheduler_test_data_generator.py0a dummy module containing only one trainable parameter.STRING
HIGH…ata_generation/adamw_test/adamw_test_data_generator.py0a dummy module containing only one trainable parameter.STRING
HIGH…st_data_generation/sgd_test/sgd_test_data_generator.py0a dummy module containing only one trainable parameter.STRING
HIGHonnxruntime/test/python/quantization/test_onnx_model.py0helper function to generate initializers for test inputsSTRING
HIGHonnxruntime/test/python/quantization/op_test_utils.py0helper function to generate initializers for test inputsSTRING
HIGH…xruntime/test/python/quantization/test_conv_dynamic.py0helper function to generate initializers for test inputsSTRING
HIGHonnxruntime/test/python/quantization/test_qdq.py0helper function to generate initializers for test inputsSTRING
HIGH…nxruntime/test/python/quantization/test_calibration.py0helper function to generate initializers for test inputsSTRING
HIGHonnxruntime/test/python/transformers/test_gqa.py0print percentile statistics (75%, 95%, 99%) for a difference tensor. this helps assess parity quality beyond just max diSTRING
HIGHonnxruntime/test/python/transformers/test_qmoe_cuda.py0print percentile statistics (75%, 95%, 99%) for a difference tensor. this helps assess parity quality beyond just max diSTRING
HIGHonnxruntime/test/python/transformers/test_moe_cuda.py0print percentile statistics (75%, 95%, 99%) for a difference tensor. this helps assess parity quality beyond just max diSTRING
HIGH…test/python/transformers/test_onnx_attention/common.py0print percentile statistics (75%, 95%, 99%) for a difference tensor. this helps assess parity quality beyond just max diSTRING
HIGHonnxruntime/test/python/transformers/benchmark_qmoe.py0benchmark tests for qmoe swiglu performance measurement.STRING
HIGHonnxruntime/test/python/transformers/test_qmoe_cuda.py0benchmark tests for qmoe swiglu performance measurement.STRING
HIGHonnxruntime/test/python/transformers/test_qmoe_cpu.py0benchmark tests for qmoe swiglu performance measurement.STRING
HIGHonnxruntime/test/python/transformers/benchmark_qmoe.py0comprehensive throughput benchmark for qmoe swiglu across different configurations.STRING
44 more matches not shown…
Deep Nesting550 hits · 496 pts
SeverityFileLineSnippetContext
LOWsetup.py834CODE
LOWtools/ci_build/build.py156CODE
LOWtools/ci_build/build.py323CODE
LOWtools/ci_build/build.py1325CODE
LOWtools/ci_build/build.py1689CODE
LOWtools/ci_build/build.py1903CODE
LOWtools/ci_build/build.py1923CODE
LOWtools/ci_build/build.py2006CODE
LOWtools/ci_build/build.py2280CODE
LOWtools/ci_build/op_registration_utils.py123CODE
LOWtools/ci_build/compile_triton.py22CODE
LOWtools/ci_build/manage_java_artifacts.py109CODE
LOWtools/ci_build/linux_java_copy_strip_binary.py74CODE
LOWtools/ci_build/build_args.py41CODE
LOWtools/ci_build/build_args.py895CODE
LOWtools/ci_build/reduce_op_kernels.py234CODE
LOWtools/ci_build/cuda_plugin_parity_report.py100CODE
LOWtools/ci_build/cuda_plugin_parity_report.py167CODE
LOWtools/ci_build/cuda_plugin_parity_report.py212CODE
LOWtools/ci_build/set_plugin_ep_build_variables.py21CODE
LOWtools/ci_build/github/apple/test_apple_packages.py22CODE
LOW…build/github/windows/post_binary_sizes_to_dashboard.py41CODE
LOWtools/ci_build/github/windows/sign_java_artifacts.py12CODE
LOWtools/ci_build/github/windows/sign_java_artifacts.py25CODE
LOWtools/python/compile_contributors.py79CODE
LOWtools/python/compile_contributors.py184CODE
LOWtools/python/compile_contributors.py317CODE
LOWtools/python/update_ctest_path.py17CODE
LOWtools/python/run_android_emulator.py57CODE
LOWtools/python/cherry_pick_utils.py9CODE
LOWtools/python/create_reduced_build_config.py21CODE
LOWtools/python/create_reduced_build_config.py76CODE
LOWtools/python/run_packaging_pipelines.py114CODE
LOWtools/python/run_packaging_pipelines.py374CODE
LOWtools/python/sparsify_initializers.py57CODE
LOWtools/python/gen_contrib_doc.py90CODE
LOWtools/python/gen_contrib_doc.py115CODE
LOWtools/python/gen_contrib_doc.py306CODE
LOWtools/python/dump_ort_model.py41CODE
LOWtools/python/dump_ort_model.py86CODE
LOWtools/python/run_workflows_for_branch.py23CODE
LOWtools/python/gen_opkernel_doc.py96CODE
LOWtools/python/example_operator_perf_test.py72CODE
LOWtools/python/resolve_absl_deps_dynamic.py86CODE
LOWtools/python/fix_long_lines.py17CODE
LOWtools/python/benchmark_mmap_ort.py88CODE
LOWtools/python/benchmark_mmap_ort.py182CODE
LOWtools/python/benchmark_mmap_ort.py317CODE
LOWtools/python/ort_test_dir_utils.py25CODE
LOWtools/python/ort_test_dir_utils.py74CODE
LOWtools/python/ort_test_dir_utils.py194CODE
LOWtools/python/ort_test_dir_utils.py117CODE
LOWtools/python/onnx2tfevents.py262CODE
LOWtools/python/onnx2tfevents.py290CODE
LOWtools/python/onnx2tfevents.py303CODE
LOWtools/python/onnx2tfevents.py324CODE
LOWtools/python/cherry_pick.py85CODE
LOWtools/python/cherry_pick.py147CODE
LOW…ython/find_optimizer_opset_version_updates_required.py32CODE
LOW…ython/find_optimizer_opset_version_updates_required.py65CODE
490 more matches not shown…
Unused Imports406 hits · 382 pts
SeverityFileLineSnippetContext
LOWtools/ci_build/build.py5CODE
LOWtools/ci_build/build.py1799CODE
LOWtools/ci_build/build.py1885CODE
LOWtools/ci_build/build.py1886CODE
LOWtools/ci_build/op_registration_utils.py8CODE
LOWtools/ci_build/update_tsaoptions.py3CODE
LOWtools/ci_build/set-trigger-rules.py7CODE
LOWtools/ci_build/patch_manylinux.py4CODE
LOWtools/ci_build/reduce_op_kernels.py4CODE
LOW…ols/ci_build/upload_python_package_to_azure_storage.py4CODE
LOWtools/ci_build/op_registration_validator.py8CODE
LOWtools/ci_build/github/apple/package_release_tasks.py5CODE
LOWtools/ci_build/github/apple/build_apple_framework.py5CODE
LOW…ols/ci_build/github/apple/get_simulator_device_info.py5CODE
LOWtools/ci_build/github/apple/build_settings_utils.py1CODE
LOWtools/python/wgsl_gen.py22CODE
LOWtools/python/run_android_emulator.py4CODE
LOWtools/python/run_adb.py4CODE
LOWtools/python/sparsify_initializers.py8CODE
LOWtools/python/gen_contrib_doc.py15CODE
LOWtools/python/gen_opkernel_doc.py6CODE
LOWtools/python/resolve_absl_deps_dynamic.py4CODE
LOWtools/python/trigger_and_wait_pipelines.py4CODE
LOWtools/python/util/run.py3CODE
LOWtools/python/util/get_azcopy.py3CODE
LOWtools/python/util/make_dynamic_shape_fixed.py4CODE
LOWtools/python/util/optimize_onnx_model.py4CODE
LOWtools/python/util/onnx_model_utils.py3CODE
LOWtools/python/util/__init__.py4CODE
LOWtools/python/util/__init__.py6CODE
LOWtools/python/util/__init__.py6CODE
LOWtools/python/util/__init__.py6CODE
LOWtools/python/util/__init__.py7CODE
LOWtools/python/util/__init__.py8CODE
LOWtools/python/util/__init__.py9CODE
LOWtools/python/util/__init__.py9CODE
LOWtools/python/util/__init__.py9CODE
LOWtools/python/util/__init__.py9CODE
LOWtools/python/util/__init__.py9CODE
LOWtools/python/util/__init__.py18CODE
LOWtools/python/util/__init__.py20CODE
LOWtools/python/util/__init__.py29CODE
LOWtools/python/util/reduced_build_config_parser.py3CODE
LOWtools/python/util/reduced_build_config_parser.py9CODE
LOWtools/python/util/__init__append.py6CODE
LOWtools/python/util/convert_onnx_models_to_ort.py5CODE
LOWtools/python/util/file_utils.py3CODE
LOWtools/python/util/pytorch_export_helpers.py4CODE
LOWtools/python/util/mobile_helpers/usability_checker.py3CODE
LOW…hon/util/mobile_helpers/test/test_usability_checker.py3CODE
LOW…til/ort_format_model/operator_type_usage_processors.py3CODE
LOWtools/python/util/ort_format_model/__init__.py21CODE
LOWtools/python/util/ort_format_model/__init__.py21CODE
LOWtools/python/util/ort_format_model/__init__.py21CODE
LOWtools/python/util/ort_format_model/__init__.py26CODE
LOWtools/python/util/ort_format_model/__init__.py27CODE
LOWtools/python/util/android/__init__.py4CODE
LOWtools/python/util/android/__init__.py4CODE
LOWtools/python/util/android/__init__.py4CODE
LOWtools/python/util/android/__init__.py4CODE
346 more matches not shown…
Excessive Try-Catch Wrapping226 hits · 288 pts
SeverityFileLineSnippetContext
MEDIUMsetup.py337 print("Error importing dependencies:")CODE
LOWsetup.py765 except Exception:CODE
LOWsetup.py776 except Exception:CODE
MEDIUMsetup.py761def check_date_format(date_str):CODE
MEDIUMsetup.py768def reformat_run_count(count_str):CODE
MEDIUMtools/ci_build/build.py1918 print(f"Error decoding JSON from version.json in {cuda_home}.")CODE
LOWtools/ci_build/prepare_macos_package.py183 except Exception as e:CODE
LOWtools/ci_build/linux_java_copy_strip_binary.py195 except Exception as e:CODE
LOWtools/ci_build/build_args.py422 except Exception as e:CODE
LOWtools/ci_build/cuda_plugin_parity_report.py560 except Exception as e:CODE
MEDIUMtools/ci_build/cuda_plugin_parity_report.py562 print(f"Error: failed to register plugin EP '{plugin_ep_name}': {e}", file=sys.stderr)CODE
MEDIUMtools/ci_build/cuda_plugin_parity_report.py692 print("Error: Could not find repo root. Use --repo-root flag.", file=sys.stderr)CODE
LOWtools/ci_build/set_plugin_ep_build_variables.py77 except Exception as e:CODE
LOWtools/ci_build/github/windows/sign_java_artifacts.py73 except Exception as e:CODE
MEDIUMtools/ci_build/github/windows/sign_java_artifacts.py74 print(f"Error generating {algorithm} hash for {file_path}: {e}")CODE
MEDIUMtools/ci_build/github/windows/sign_java_artifacts.py88 print(f"Error: Directory not found at '{jar_file_directory}'", file=sys.stderr)CODE
MEDIUMtools/ci_build/github/windows/sign_java_artifacts.py110 print(f"Error: GPG executable not found at '{gpg_exe_path}'.", file=sys.stderr)CODE
MEDIUMtools/ci_build/github/windows/jar_packaging.py23 print("Error: The 'semver' package is not installed. Please add it to your requirements.txt.", file=sys.stderr)CODE
MEDIUMtools/ci_build/github/windows/jar_packaging.py75 print(f"Error: 7z failed to archive '{file_to_add.name}' to '{archive_path.name}'.", file=sys.stderr)CODE
MEDIUMtools/ci_build/github/windows/jar_packaging.py102 print(f"Error: 7z failed to archive directory '{source_dir.name}' to '{archive_path.name}'.", file=sys.stderr)CODE
MEDIUMtools/ci_build/github/windows/jar_packaging.py121 print(f"Error: Version '{version_string}' is not valid. Reason: {e}", file=sys.stderr)CODE
MEDIUMtools/ci_build/github/windows/jar_packaging.py135 print(f"Error: Missing companion sources JAR. Expected: {sources_jar_path.name}", file=sys.stderr)CODE
MEDIUMtools/ci_build/github/windows/jar_packaging.py139 print(f"Error: Missing companion javadoc JAR. Expected file like: {base_stem}-javadoc.jar", file=sys.stderr)CODE
MEDIUMtools/ci_build/github/windows/jar_packaging.py167 print(f"Error: Expected custom op library '{custom_lib_file}' not found in {platform_path}", file=sys.stderr)CODE
MEDIUMtools/ci_build/github/windows/jar_packaging.py189 print(f"Error: Primary package directory not found at '{primary_package_dir}'", file=sys.stderr)CODE
MEDIUMtools/ci_build/github/windows/jar_packaging.py252 print(f"Error: Base 'testing.jar' not found at '{final_test_archive}'.", file=sys.stderr)CODE
MEDIUMtools/ci_build/github/windows/jar_packaging.py260 print(f"Error: Required platform artifact directory not found: {platform_full_path}", file=sys.stderr)CODE
MEDIUMtools/ci_build/github/windows/jar_packaging.py277 print("Error: This script is intended to be run on Windows.", file=sys.stderr)CODE
LOWtools/ci_build/github/windows/jar_packaging.py312 except Exception as e:CODE
MEDIUMtools/python/update_version.py120 print("Error: Could not import 'is_windows' and 'run' from a 'util' module.", file=sys.stderr)CODE
MEDIUMtools/python/update_version.py134 print(f"Error: 'fnm' is being used, but the version file '{nvmrc_path}' was not found.", file=sys.stderr)CODE
MEDIUMtools/python/update_version.py151 print("Error: Could not find 'node' and 'npm' in your PATH.", file=sys.stderr)CODE
MEDIUMtools/python/update_version.py195 print(f"Error: '{version_file}' not found.", file=sys.stderr)CODE
MEDIUMtools/python/update_ctest_path.py52 print(f"Error: Could not find old source/build directory paths in {file_path}", file=sys.stderr)CODE
MEDIUMtools/python/update_ctest_path.py86 print(f"Error during file processing: {e}", file=sys.stderr)CODE
MEDIUMtools/python/update_ctest_path.py93 print(f"Error replacing file: {e}", file=sys.stderr)CODE
MEDIUMtools/python/update_ctest_path.py121 print(f"Error: CTest file not found at '{args.ctest_file}'", file=sys.stderr)CODE
LOWtools/python/update_ctest_path.py126 except Exception as e:CODE
MEDIUMtools/python/cherry_pick_utils.py16 print(f"Error running command: {log_str}", file=sys.stderr)CODE
MEDIUMtools/python/cherry_pick_utils.py24 print(f"Error: '{cmd}' command not found.", file=sys.stderr)CODE
LOWtools/python/cherry_pick_utils.py31 except Exception as e:CODE
MEDIUMtools/python/cherry_pick_utils.py42 print("Error: This script must be run inside a git repository.", file=sys.stderr)CODE
MEDIUMtools/python/cherry_pick_utils.py48 print("Error: GitHub CLI (gh) not found or not in PATH.", file=sys.stderr)CODE
MEDIUMtools/python/cherry_pick_utils.py60 print("Error: GitHub CLI not authenticated. Please run 'gh auth login'.", file=sys.stderr)CODE
MEDIUMtools/python/cherry_pick_utils.py63 print("Error: GitHub CLI (gh) not found.", file=sys.stderr)CODE
LOWtools/python/run_packaging_pipelines.py93 except Exception as e:CODE
LOWtools/python/run_packaging_pipelines.py260 except Exception as e:CODE
LOWtools/python/gen_opkernel_doc.py84 except Exception as e:CODE
LOWtools/python/gen_opkernel_doc.py90 except Exception as e:CODE
MEDIUMtools/python/resolve_absl_deps_dynamic.py184 print(f"Error: Failed to download Abseil version '{version}'.", file=sys.stderr)CODE
MEDIUMtools/python/resolve_absl_deps_dynamic.py226 print(f"Error: Input file '{args.input_file}' not found.", file=sys.stderr)CODE
MEDIUMtools/python/resolve_absl_deps_dynamic.py241 print(f"An error occurred during resolution: {e}", file=sys.stderr)CODE
LOWtools/python/trigger_and_wait_pipelines.py320 except Exception as e:CODE
LOWtools/python/PythonTools.md168except Exception:CODE
MEDIUMtools/python/cherry_pick.py63 print(f"Error parsing gh output: {e}", file=sys.stderr)CODE
LOWtools/python/util/convert_onnx_models_to_ort.py171 except Exception as e:CODE
MEDIUMtools/python/util/convert_onnx_models_to_ort.py172 print(f"Error converting {model}: {e}")CODE
LOWtools/python/wgsl_template/test/test_in_tree_smoke.py58 except Exception:CODE
LOWtools/python/wgsl_template/test/test_parser.py267 except Exception as e:CODE
LOWtools/python/wgsl_template/test/test_generator.py239 except Exception as e:CODE
166 more matches not shown…
AI Slop Vocabulary57 hits · 146 pts
SeverityFileLineSnippetContext
MEDIUMtools/ci_build/manage_java_artifacts.py84 # Adding these makes the command more robust and less prone to errorsCOMMENT
MEDIUMtools/ci_build/github/Doxyfile_csharp.cfg1272# it is more robust and this tag (HTML_STYLESHEET) will in the future becomeCOMMENT
MEDIUMtools/ci_build/github/Doxyfile_csharp.cfg1282# standard style sheet and is therefore more robust against future updates.COMMENT
MEDIUM…thub/azure-pipelines/py-cuda-package-test-pipeline.yml11 # To utilize gpu resource more efficiently, run GPU job only after all cpus jobs succeedCOMMENT
MEDIUMtools/python/wgsl_template/test/test_parser.py236 # and need a different harness.COMMENT
MEDIUMonnxruntime/core/mickey/blk_q4/f16_gemm_sm80.h46 // We pack 4 weights into one 16b element, so as to leverage cutlass tile iteratorsCOMMENT
MEDIUMonnxruntime/core/mickey/blk_q4/f16_prepack_sm80.h51 // We pack 4 weights into one 16b element, so we can leverage cutlass tile iteratorsCOMMENT
MEDIUM…emm/threadblock/optional_predicated_tile_access_iter.h28/// iterator becomes no-op with minimal runtime footprint. Also, it utilize theCOMMENT
MEDIUM…emm/threadblock/optional_predicated_tile_access_iter.h29/// higher numbered threads in the threadblock when the iterator can not utilizeCOMMENT
MEDIUM…emm/threadblock/optional_predicated_tile_access_iter.h43 /// will utilize the higher numbered threadsCOMMENT
MEDIUM…q4gemm/threadblock/optional_regular_tile_access_iter.h35/// becomes no-op with minimal runtime footprint. Also, it utilize the higherCOMMENT
MEDIUM…q4gemm/threadblock/optional_regular_tile_access_iter.h36/// numbered threads in the threadblock when the iterator can not utilize allCOMMENT
MEDIUM…q4gemm/threadblock/optional_regular_tile_access_iter.h47 /// will utilize the higher numbered threadsCOMMENT
MEDIUMonnxruntime/core/mickey/gemm/kernel/quant_b4_gemm.h121 // Need 4 tiles to fully utilize ldmatrix. And.....COMMENT
MEDIUMonnxruntime/core/mickey/gemm/kernel/quant_b4_gemm.h151 // to load 4 tiles, fully utilize the ldmatrix instruction.COMMENT
MEDIUMonnxruntime/core/mickey/gemm/kernel/quant_b4_gemm.h736 using Float4 = cutlass::Array<float, 4>; // hopefully utilize 128b st.shared.b128CODE
MEDIUM…nxruntime/core/framework/prepacked_weights_container.h117 // Reference in this context means a non-owning smart pointer. Essentially, this functionCOMMENT
MEDIUM…ovider/src/Operators/DmlOperatorBatchNormalization.cpp89 // and normally we'd need to specify kernelInputIndices to Initialize, but we'll utilize DMLX's mapping instead.COMMENT
MEDIUMonnxruntime/core/mlas/lib/flashattn.cpp145 // TODO: leverage advanced instruction setsCOMMENT
MEDIUMonnxruntime/core/mlas/lib/halfgemm.cpp383 // Without PackB, to utilize memory locality, iterate full K.COMMENT
MEDIUMonnxruntime/core/mlas/lib/activate_fp16.cpp172 // leverage the fact that for our implementation tanhf(sat_cutoff) == -1.0h. NaN inputs areCOMMENT
MEDIUMonnxruntime/core/mlas/lib/activate_fp16.cpp238 // leverage the fact that for our implementation tanhf(sat_cutoff) == -1.0h. NaN inputs areCOMMENT
MEDIUMonnxruntime/test/python/transformers/test_gqa.py1991 # For past test: pipeline tests share_buffer=True only, comprehensive tests bothCOMMENT
MEDIUMonnxruntime/test/python/transformers/test_gqa.py2077 # The past-parity harness compares the full present buffer; without bufferCOMMENT
MEDIUMonnxruntime/test/python/transformers/test_mha.py214 # Lengths of arrays are prime numbers since modulo (% length) is used in non comprehensive mode.COMMENT
MEDIUMonnxruntime/test/python/transformers/test_mha.py310 # Lengths of arrays are prime numbers since modulo (% length) is used in non comprehensive mode.COMMENT
MEDIUMonnxruntime/test/unittest_util/qdq_test_utils.h622 // Essentially eveything has worked correctly if the DQ -> Transpose -> Q becomes a single Transpose and theCOMMENT
LOWonnxruntime/python/tools/quantization/base_quantizer.py410 # axis, symmetric, and reduce_range values. So, just use the first channel's values.COMMENT
LOW…time/python/tools/quantization/operators/activation.py19 # If activation is symmetric, not quantize the op and simply returnCOMMENT
MEDIUM…untime/python/tools/transformers/convert_generation.py2630 # dims need to be a multiple of 8 to leverage tensor cores.COMMENT
MEDIUM…els/torch_export_patches/patches/patch_transformers.py358 # (this alternative is not as robust as callingCOMMENT
MEDIUMonnxruntime/python/tools/tensorrt/perf/benchmark.py336 if with_binding and cpu not in ep: # other eps utilize python bindingCODE
MEDIUM…ng/test/python/orttraining_test_ort_pipeline_module.py32 """Custom dataset to facilitate loading and batching of data."""STRING
MEDIUM…ing/orttraining/python/training/ortmodule/ortmodule.py31 """Extends user's :class:`torch.nn.Module` model to leverage ONNX Runtime super fast training engine.STRING
MEDIUM…n/training/ortmodule/_gradient_accumulation_manager.py73 # TODO: Make detection of parameter update robustCOMMENT
MEDIUM…python/training/ortmodule/_graph_transition_manager.py378 # forward run. To facilitate un-flattening during subsequent ORT runs, the output schema is saved asCOMMENT
LOW…ng/ortmodule/experimental/pipe/_ort_pipeline_module.py162 # that case and just use it in forward()COMMENT
MEDIUM…hon/training/ortmodule/torch_cpp_extensions/install.py64 # Extensions might leverage CUDA versions internallyCOMMENT
LOW…ython/training/utils/hooks/_zero_offload_subscriber.py394 # STAGE3WARN#3: _post_forward_module_hook's second argument `input is not used, so we just pass a None here.COMMENT
LOW…ython/training/utils/hooks/_zero_offload_subscriber.py611 # STAGE3WARN#7: _pre_backward_module_hook's second argument `input is not used, so we just pass a None here.COMMENT
LOW…g/orttraining/python/training/ort_triton/_decompose.py342 # The decompose process will be called recursively, if it's already a decomposed result, just return.COMMENT
LOW…g/orttraining/python/training/ort_triton/_decompose.py349 # The decompose process will be called recursively, if it's already a decomposed result, just return.COMMENT
LOW…g/orttraining/python/training/ort_triton/_decompose.py353 # The decompose process will be called recursively, if it's already a decomposed result, just return.COMMENT
LOW…ining/python/training/ort_triton/kernel/_flash_attn.py135 # [2022-10-30] TD: Triton bug - in the case of EVEN_M=True and EVEN_N=False, if we just callCOMMENT
LOW…ining/python/training/ort_triton/kernel/_flash_attn.py321 # if we just call tl.store(dv_ptrs), there's a race conditionCOMMENT
LOW…ining/python/training/ort_triton/kernel/_flash_attn.py416 # if we just call tl.load(k_ptrs), we get the wrong output!COMMENT
LOW…ining/python/training/ort_triton/kernel/_flash_attn.py491 # [2022-11-01] TD: Triton bug, there's a race condition if we just use m_mask and not d_mask.COMMENT
MEDIUMinclude/onnxruntime/core/framework/float4.h5// if they would like to leverage the CUDA implementation for the conversion routinesCOMMENT
MEDIUMinclude/onnxruntime/core/platform/threadpool.h87// dynamic balancing behavior helps make performance robust to anyCOMMENT
MEDIUMinclude/onnxruntime/core/common/float8.h5// if they would like to leverage the CUDA implementation for the conversion routinesCOMMENT
MEDIUMwinml/lib/Api/LearningModelSession.h70 // LearningModelBinding needs to leverage the lockCOMMENT
MEDIUM…ocs/_exported_templates/default/styles/docfx.vendor.js1!function(e,t){"use strict";"object"==typeof module&&"object"==typeof module.exports?module.exports=e.document?t(e,!0):fCODE
MEDIUM…ocs/_exported_templates/default/styles/docfx.vendor.js1!function(e,t){"use strict";"object"==typeof module&&"object"==typeof module.exports?module.exports=e.document?t(e,!0):fCODE
MEDIUM…ocs/_exported_templates/default/styles/docfx.vendor.js1!function(e,t){"use strict";"object"==typeof module&&"object"==typeof module.exports?module.exports=e.document?t(e,!0):fCODE
MEDIUM…arp/src/Microsoft.ML.OnnxRuntime/OrtEpDevice.shared.cs52 /// that the execution provider can utilize.COMMENT
MEDIUM…arp/src/Microsoft.ML.OnnxRuntime/OrtEpDevice.shared.cs114 /// The hardware device that the execution provider can utilize.COMMENT
MEDIUMcsharp/src/Microsoft.ML.OnnxRuntime/OrtEnv.shared.cs706 /// Devices the execution provider can utilize are added to the values returned by GetEpDevices() and canCOMMENT
AI Structural Patterns155 hits · 131 pts
SeverityFileLineSnippetContext
LOWtools/ci_build/compile_triton.py25CODE
LOW…ols/ci_build/github/apple/get_simulator_device_info.py142CODE
LOWtools/python/util/run.py13CODE
LOW…ation/lr_scheduler/lr_scheduler_test_data_generator.py40CODE
LOW…ata_generation/adamw_test/adamw_test_data_generator.py20CODE
LOW…ata_generation/adamw_test/adamw_test_data_generator.py37CODE
LOW…st_data_generation/sgd_test/sgd_test_data_generator.py20CODE
LOW…st_data_generation/sgd_test/sgd_test_data_generator.py37CODE
LOW…/transform/recompute/recompute_test_graph_generator.py27CODE
LOW…/testdata/training_api/ort_format/prepare_artifacts.py25CODE
LOW…runtime/test/python/test_pytorch_export_contrib_ops.py65CODE
LOW…nxruntime/test/python/onnxruntime_test_float8_gemm8.py27CODE
LOW…ntime/test/python/quantization/test_quantize_static.py104CODE
LOWonnxruntime/test/python/transformers/test_gqa.py919CODE
LOWonnxruntime/test/python/transformers/profile_gqa.py61CODE
LOW…untime/test/python/transformers/test_mha_flash_attn.py282CODE
LOW…untime/test/python/transformers/test_mha_flash_attn.py300CODE
LOW…time/test/python/transformers/qwen3_model_generator.py298CODE
LOWonnxruntime/test/python/transformers/test_gqa_cpu.py152CODE
LOWonnxruntime/test/python/transformers/test_gqa_cpu.py393CODE
LOWonnxruntime/test/python/transformers/test_gqa_cpu.py777CODE
LOWonnxruntime/test/python/transformers/test_gqa_cpu.py935CODE
LOWonnxruntime/test/python/transformers/test_gqa_cpu.py1158CODE
LOWonnxruntime/test/python/transformers/test_gqa_cpu.py1256CODE
LOWonnxruntime/test/python/transformers/test_gqa_cpu.py1324CODE
LOWonnxruntime/test/python/transformers/test_gqa_cpu.py1609CODE
LOWonnxruntime/test/python/transformers/test_gqa_cpu.py1869CODE
LOWonnxruntime/test/python/transformers/test_gqa_cpu.py2162CODE
LOWonnxruntime/test/python/transformers/benchmark_mha.py85CODE
LOWonnxruntime/test/python/transformers/test_qmoe_cuda.py266CODE
LOWonnxruntime/test/python/transformers/gqa_test_helper.py162CODE
LOWonnxruntime/test/python/transformers/gqa_test_helper.py288CODE
LOWonnxruntime/test/python/transformers/test_whisper.py220CODE
LOW…test/python/transformers/test_parity_neox_attention.py366CODE
LOW…/test/python/transformers/test_paged_attention_cuda.py343CODE
LOW…time/test/python/transformers/test_sparse_attention.py45CODE
LOW…ntime/test/python/transformers/gpt2_model_generator.py580CODE
LOW…ntime/test/python/transformers/gpt2_model_generator.py761CODE
LOW…/transformers/test_parity_huggingface_gpt_attention.py168CODE
LOWonnxruntime/test/python/transformers/test_moe_cuda.py1236CODE
LOWonnxruntime/test/python/transformers/test_qmoe_cpu.py388CODE
LOW…rs/test_onnx_attention/test_tensorscatter_attention.py144CODE
LOWonnxruntime/python/tools/quantization/quantize.py247CODE
LOWonnxruntime/python/tools/quantization/quantize.py509CODE
LOWonnxruntime/python/tools/quantization/quantize.py914CODE
LOWonnxruntime/python/tools/quantization/quantize.py44CODE
LOWonnxruntime/python/tools/quantization/quantize.py99CODE
LOWonnxruntime/python/tools/quantization/quantize.py431CODE
LOW…me/python/tools/quantization/static_quantize_runner.py42CODE
LOW…me/python/tools/quantization/matmul_nbits_quantizer.py142CODE
LOW…me/python/tools/quantization/matmul_nbits_quantizer.py236CODE
LOW…me/python/tools/quantization/matmul_nbits_quantizer.py1477CODE
LOW…nxruntime/python/tools/quantization/shape_inference.py25CODE
LOWonnxruntime/python/tools/quantization/calibrate.py169CODE
LOWonnxruntime/python/tools/quantization/calibrate.py384CODE
LOWonnxruntime/python/tools/quantization/calibrate.py624CODE
LOW…on/tools/quantization/neural_compressor/weight_only.py420CODE
LOW…on/tools/quantization/neural_compressor/weight_only.py604CODE
LOW…on/tools/quantization/neural_compressor/weight_only.py744CODE
LOW…ols/quantization/execution_providers/qnn/preprocess.py22CODE
95 more matches not shown…
Redundant / Tautological Comments82 hits · 124 pts
SeverityFileLineSnippetContext
LOWtools/ci_build/prepare_macos_package.py34 # Check if any part of the path is a .dSYM directory.COMMENT
LOWtools/ci_build/set-trigger-rules.py42 # Open the file and read its linesCOMMENT
LOWtools/ci_build/build_args.py987 # Check if cmake_generator attribute exists (it might if --use_xcode was used)STRING
LOW…e-pipelines/templates/setup-feeds-and-python-steps.yml119 # Check if python is available in PATHCOMMENT
LOW…build/github/azure-pipelines/templates/setup-maven.yml23 # Check if the download was successfulCOMMENT
LOW…build/github/azure-pipelines/templates/setup-maven.yml34 # Check if the extraction was successfulCOMMENT
LOW…ls/ci_build/github/linux/build_linux_python_package.sh27 # Check if OPTARG is empty or starts with a hyphen, indicating a missing or invalid argument for -pCOMMENT
LOW…ls/ci_build/github/linux/build_linux_python_package.sh114 # Check if the Python executable or its directory existsCOMMENT
LOW…i_build/github/android/build_aar_and_copy_artifacts.sh30# Check if the include ops config file exists and modify command if it doesCOMMENT
LOWtools/python/update_version.py125 # Check if node and npm are directly available in the system's PATH.COMMENT
LOWtools/python/compile_contributors.py216 # Check if it's a cherry-pick round PRCOMMENT
LOWtools/python/cherry_pick.py110 # Check if it's a cherry-pick / meta-PRCOMMENT
LOWtools/python/util/reduced_build_config_parser.py7# Check if the flatbuffers module is available. If not we cannot handle type reduction information in the config.COMMENT
LOWtools/python/util/android/android.py236 # Verify if the emulator is now runningCOMMENT
LOWtools/python/wgsl_template/__init__.py97 # Write files. Idempotent: only overwrite when content differs.COMMENT
LOWtools/nuget/generate_nuspec_for_native_nuget.py89 # Check if the file has digits like onnxruntime.1.8.0.dylib. We can skip such thingsCOMMENT
LOWtools/nuget/validate_package.py341 # Check if the relevant dlls are present in the Nuget/ZipCOMMENT
LOWtools/nuget/validate_package.py357 # Check if the Nuget has been signedCOMMENT
LOWonnxruntime/__init__.py404 # Check if CUDA version is supported (12.x or 13.x+)COMMENT
LOWonnxruntime/__init__.py429 # Check if torch CUDA version matches onnxruntime CUDA versionCOMMENT
LOWonnxruntime/test/testdata/dmmha_inside_mha_data.py171# Print values in format for onnxruntime/test/testdata/attention/attention_test_data.txtCOMMENT
LOW…runtime/test/python/quantization/bench_matmul_8bits.py496 # Print results to consoleCOMMENT
LOW…runtime/test/python/quantization/bench_matmul_8bits.py663 # Check if k is divisible by block_size for the single config caseCOMMENT
LOW…time/test/python/transformers/test_sparse_attention.py408 # Check if the past_key_cache and new_key have compatible shapesCOMMENT
LOWonnxruntime/test/common/test_cpuinfo_sysfs_fallback.py422 # Check if onnxruntime is importableSTRING
LOWonnxruntime/python/tools/layering/layer_annotate.py93 # Check if annotation already existsCOMMENT
LOWonnxruntime/python/tools/quantization/qdq_quantizer.py100 # Check if consumer node name is in the list of nodes thatCOMMENT
LOWonnxruntime/python/tools/quantization/qdq_quantizer.py139 # Check if consumer node name is in the list of nodes thatCOMMENT
LOWonnxruntime/python/tools/quantization/qdq_quantizer.py992 # Check if this tensor is already a dequantized value. If so, skip it.COMMENT
LOW…me/python/tools/quantization/tensor_quant_overrides.py483 # Check if all nodes receive the converted type (i.e., recv_nodes is None) or this nodeCOMMENT
LOW…me/python/tools/transformers/fusion_qordered_matmul.py128 # Check if weight 'B' is a constantCOMMENT
LOWonnxruntime/python/tools/transformers/fusion_options.py70 # Set default to sequence length for BERT model to use fused attention to speed up.COMMENT
LOW…e/python/tools/transformers/fusion_rotary_attention.py247 # Check if first input to Add and Unsqueeze #1 is position idsCOMMENT
LOW…e/python/tools/transformers/fusion_rotary_attention.py1373 # Check if node is "RotaryEmbedding nn.Module" exported as a functionCOMMENT
LOW…ime/python/tools/transformers/fusion_attention_unet.py901 # Check if we have a LoRA patternCOMMENT
LOW…xruntime/python/tools/transformers/fusion_layernorm.py58 # Check if Sub --> Div existsCOMMENT
LOW…xruntime/python/tools/transformers/fusion_layernorm.py64 # Check if Sub --> Cast --> DivCOMMENT
LOW…xruntime/python/tools/transformers/fusion_attention.py237 # Check if concat node for (B,1,S,T) --> (B,N,S,T) already existsCOMMENT
LOW…python/tools/transformers/fusion_qordered_attention.py45 # Check if the second input to Reshape flows through a Constant nodeCOMMENT
LOW…untime/python/tools/transformers/convert_generation.py1837 # Check if root_input to Q/K/V paths is the sameCOMMENT
LOW…untime/python/tools/transformers/convert_generation.py1840 # Check if Q/K/V paths all have bias or all don't have biasCOMMENT
LOWonnxruntime/python/tools/transformers/run_benchmark.sh35# Set this to true to enable bfloat16 fastmath gemm kernels on aarch64 platforms with bfloat16 supportCOMMENT
LOWonnxruntime/python/tools/transformers/run_benchmark.sh68# Set it to false to skip testing. You can use it to dry run this script with the log file.COMMENT
LOW…time/python/tools/transformers/fusion_constant_fold.py39 # Check if Transpose node only has one input and one outputCOMMENT
LOW…time/python/tools/transformers/fusion_constant_fold.py44 # Check if input is initializer dataCOMMENT
LOW…time/python/tools/transformers/fusion_constant_fold.py69 # Check if initializer data is 2DCOMMENT
LOW…time/python/tools/transformers/fusion_constant_fold.py100 # Add node to list of nodes to removeCOMMENT
LOW…time/python/tools/transformers/fusion_constant_fold.py111 # Check if Transpose node only has one input and one outputCOMMENT
LOW…time/python/tools/transformers/fusion_constant_fold.py116 # Check if parent node is Transpose node with only one input and one outputCOMMENT
LOW…time/python/tools/transformers/fusion_constant_fold.py141 # Add node to list of nodes to removeCOMMENT
LOW…time/python/tools/transformers/fusion_skiplayernorm.py67 # Check if b is a broadcastable skip for aCOMMENT
LOW…time/python/tools/transformers/fusion_skiplayernorm.py70 # Check if a is a broadcastable skip for bCOMMENT
LOWonnxruntime/python/tools/transformers/onnx_model.py1004 # Check if node output is an input of a subgraph node and not an input to a node in the main graphCOMMENT
LOWonnxruntime/python/tools/transformers/onnx_model.py1397 # Check if tensors are allcloseCOMMENT
LOWonnxruntime/python/tools/transformers/fusion_mha_dit.py398 # Check if K^T comes from Transpose(perm=0,1,3,2) — if so, use K_BNSH directlyCOMMENT
LOW…on/tools/transformers/models/phi2/inference_example.py269 # Check if we previously reached EOS token id or if generated token id is EOS token idCOMMENT
LOW…on/tools/transformers/models/phi2/inference_example.py309 # Set logits to zeros for next inference run and re-use memory bufferCOMMENT
LOW…me/python/tools/transformers/models/llama/benchmark.py57 # Set max_seq_len to 2048 for Microsoft LLaMA-2 model since that is the max value currently supportedCOMMENT
LOW…me/python/tools/transformers/models/llama/benchmark.py58 # Set max_seq_len to config value for other modelsCOMMENT
LOW…me/python/tools/transformers/models/llama/benchmark.py678 # Check if past_present_share_buffer can be enabled (only for FP16 models with GQA)COMMENT
22 more matches not shown…
Modern Structural Boilerplate93 hits · 104 pts
SeverityFileLineSnippetContext
LOWtools/python/sparsify_initializers.py18logger = logging.getLogger(__name__)CODE
LOWtools/python/trigger_and_wait_pipelines.py22logger = logging.getLogger(__name__)CODE
LOWtools/python/wgsl_template/__init__.py138__all__ = [CODE
LOWtools/python/wgsl_template/code_generator/__init__.py36__all__ = [CODE
LOWonnxruntime/core/flatbuffers/schema/compile_schema.py49__all__ = [splitext(basename(f))[0] for f in modules if isfile(f) and not f.endswith('__init__.py')]STRING
LOW…me/core/flatbuffers/ort_flatbuffers_py/fbs/__init__.py4__all__ = [splitext(basename(f))[0] for f in modules if isfile(f) and not f.endswith('__init__.py')]CODE
LOW…ation/lr_scheduler/lr_scheduler_test_data_generator.py13logger = logging.getLogger(__name__)CODE
LOW…time/test/python/transformers/cuda_plugin_ep_helper.py16logger = logging.getLogger(__name__)CODE
LOWonnxruntime/python/onnxruntime_inference_collection.py94 def set_adapter_version(self, adapter_version: int) -> None:CODE
LOWonnxruntime/python/onnxruntime_inference_collection.py100 def set_model_version(self, model_version: int) -> None:CODE
LOWonnxruntime/python/onnxruntime_inference_collection.py106 def set_parameters(self, params: dict[str, OrtValue]) -> None:CODE
LOWonnxruntime/python/onnxruntime_inference_collection.py261 def set_providers(self, providers=None, provider_options=None) -> None:CODE
LOWonnxruntime/python/onnxruntime_inference_collection.py1332 def update_inplace(self, data) -> None:CODE
LOWonnxruntime/python/tools/symbolic_shape_infer.py21logger = logging.getLogger(__name__)CODE
LOW…ime/python/tools/quantization/matmul_bnb4_quantizer.py21logger = logging.getLogger(__name__)CODE
LOWonnxruntime/python/tools/quantization/preprocess.py13logger = logging.getLogger(__name__)CODE
LOW…me/python/tools/quantization/matmul_nbits_quantizer.py34logger = logging.getLogger(__name__)CODE
LOW…nxruntime/python/tools/quantization/shape_inference.py22logger = logging.getLogger(__name__)CODE
LOWonnxruntime/python/tools/microbench/benchmark.py17logger = logging.getLogger(__name__)CODE
LOW…time/python/tools/transformers/onnx_model_conformer.py12logger = logging.getLogger(__name__)CODE
LOW…e/python/tools/transformers/fusion_rotary_attention.py13logger = logging.getLogger(__name__)CODE
LOW…ime/python/tools/transformers/fusion_bart_attention.py12logger = logging.getLogger(__name__)CODE
LOW…untime/python/tools/transformers/onnx_model_bert_tf.py13logger = logging.getLogger(__name__)CODE
LOW…runtime/python/tools/transformers/io_binding_helper.py16logger = logging.getLogger(__name__)CODE
LOW…nxruntime/python/tools/transformers/onnx_model_unet.py21logger = logging.getLogger(__name__)CODE
LOW…nxruntime/python/tools/transformers/onnx_model_bart.py15logger = logging.getLogger(__name__)CODE
LOW…xruntime/python/tools/transformers/fusion_quickgelu.py12logger = logging.getLogger(__name__)CODE
LOW…nxruntime/python/tools/transformers/quantize_helper.py18logger = logging.getLogger(__name__)CODE
LOW…nxruntime/python/tools/transformers/onnx_model_gpt2.py14logger = logging.getLogger(__name__)CODE
LOW…untime/python/tools/transformers/shape_infer_helper.py29logger = logging.getLogger(__name__)CODE
LOW…ython/tools/transformers/fusion_conformer_attention.py10logger = logging.getLogger(__name__)CODE
LOWonnxruntime/python/tools/transformers/past_helper.py11logger = logging.getLogger(__name__)CODE
LOW…xruntime/python/tools/transformers/benchmark_helper.py28logger = logging.getLogger(__name__)CODE
LOW…nxruntime/python/tools/transformers/onnx_model_tnlr.py13logger = logging.getLogger(__name__)CODE
LOW…nxruntime/python/tools/transformers/onnx_model_sam2.py15logger = logging.getLogger(__name__)CODE
LOW…nxruntime/python/tools/transformers/shape_optimizer.py27logger = logging.getLogger(__name__)CODE
LOWonnxruntime/python/tools/transformers/float16.py26logger = logging.getLogger(__name__)CODE
LOW…ime/python/tools/transformers/onnx_model_bert_keras.py12logger = logging.getLogger(__name__)CODE
LOWonnxruntime/python/tools/transformers/onnx_exporter.py28logger = logging.getLogger(__name__)CODE
LOWonnxruntime/python/tools/transformers/optimizer.py47logger = logging.getLogger(__name__)CODE
LOW…nxruntime/python/tools/transformers/affinity_helper.py10logger = logging.getLogger(__name__)CODE
LOWonnxruntime/python/tools/transformers/onnx_model.py32logger = logging.getLogger(__name__)CODE
LOW…xruntime/python/tools/transformers/onnx_model_mmdit.py16logger = logging.getLogger(__name__)CODE
LOW…thon/tools/transformers/fusion_simplified_layernorm.py8logger = logging.getLogger(__name__)CODE
LOW…untime/python/tools/transformers/dynamo_onnx_helper.py25 def update_edges(self, edge_mapping: dict) -> None:CODE
LOW…e/python/tools/transformers/convert_to_packing_mode.py21logger = logging.getLogger(__name__)CODE
LOWonnxruntime/python/tools/transformers/onnx_model_t5.py16logger = logging.getLogger(__name__)CODE
LOW…time/python/tools/transformers/models/t5/t5_decoder.py24logger = logging.getLogger(__name__)CODE
LOW…time/python/tools/transformers/models/t5/t5_encoder.py12logger = logging.getLogger(__name__)CODE
LOW…ools/transformers/models/t5/t5_encoder_decoder_init.py23logger = logging.getLogger(__name__)CODE
LOW…ntime/python/tools/transformers/models/t5/t5_helper.py20logger = logging.getLogger(__name__)CODE
LOW…ansformers/models/stable_diffusion/diffusion_models.py39logger = logging.getLogger(__name__)CODE
LOW…ormers/models/stable_diffusion/engine_builder_torch.py10logger = logging.getLogger(__name__)CODE
LOW…mers/models/stable_diffusion/engine_builder_ort_trt.py19logger = logging.getLogger(__name__)CODE
LOW…nsformers/models/stable_diffusion/optimize_pipeline.py38logger = logging.getLogger(__name__)CODE
LOW…ers/models/stable_diffusion/engine_builder_ort_cuda.py20logger = logging.getLogger(__name__)CODE
LOW…/transformers/models/stable_diffusion/ort_optimizer.py26logger = logging.getLogger(__name__)CODE
LOW…ls/transformers/models/longformer/longformer_helper.py13logger = logging.getLogger(__name__)CODE
LOW…e/python/tools/transformers/models/gpt2/gpt2_tester.py18logger = logging.getLogger(__name__)CODE
LOW…e/python/tools/transformers/models/gpt2/gpt2_helper.py28logger = logging.getLogger(__name__)CODE
33 more matches not shown…
Hallucination Indicators9 hits · 95 pts
SeverityFileLineSnippetContext
CRITICALonnxruntime/test/testdata/capi_symbolic_dims.py7dim = output.type.tensor_type.shape.dim.add()CODE
CRITICALonnxruntime/test/python/onnx_backend_test_series.py71 super()._add_model_test(onnx.backend.test.case.test_case.TestCase(**attrs), kind)CODE
CRITICAL…e/python/tools/transformers/fusion_rotary_attention.py1402 self.model.model.graph.value_info.remove(old_shape_infer[0])CODE
CRITICAL…untime/python/tools/transformers/dynamo_onnx_helper.py68 self.model.model.graph.node.remove(node)CODE
CRITICAL…untime/python/tools/transformers/dynamo_onnx_helper.py70 self.model.model.graph.node.append(node)CODE
CRITICAL…untime/python/tools/transformers/dynamo_onnx_helper.py94 self.model.model.graph.node.remove(node)CODE
CRITICAL…rttraining/python/training/ort_triton/_sorted_graph.py207 node.type.tensor_type.shape.dim.add().dim_value = int(dim)CODE
CRITICAL…rttraining/python/training/ort_triton/_sorted_graph.py209 node.type.tensor_type.shape.dim.add().dim_param = str(dim)CODE
CRITICAL…ocs/_exported_templates/default/styles/docfx.vendor.js1!function(e,t){"use strict";"object"==typeof module&&"object"==typeof module.exports?module.exports=e.document?t(e,!0):fCODE
Docstring Block Structure17 hits · 85 pts
SeverityFileLineSnippetContext
HIGHtools/python/resolve_absl_deps_dynamic.py87Parse CMakeLists.txt files to build a dependency graph. Parses CMakeLists.txt files in the extracted Abseil source STRING
HIGHtools/python/resolve_absl_deps_dynamic.py166Download and extract a specific version of Abseil, then generate the dependency graph. Args: version: The ASTRING
HIGHonnxruntime/python/tools/transformers/bert_test_data.py311Find graph inputs for BERT model. First, we will deduce inputs from EmbedLayerNormalization node. If not found, STRING
HIGH…untime/python/tools/transformers/shape_infer_helper.py122Compare shape of two edges. Args: edge (str): name of edge edge_other (str): name of anSTRING
HIGH…untime/python/tools/transformers/convert_generation.py675Create OnnxRuntime session. Args: model_path (str): onnx model path use_gpu (bool): use GPU or not STRING
HIGH…untime/python/tools/transformers/convert_generation.py3072Test PyTorch performance of text generation. Args: args (argparse.Namespace): arguments parsed from commandSTRING
HIGH…untime/python/tools/transformers/convert_generation.py3546Main entry function Args: argv (Optional[List[str]], optional): _description_. Defaults to None. seSTRING
HIGHonnxruntime/python/tools/transformers/float16.py74Convert tensor float to float16. Args: tensor (TensorProto): the tensor to convert. min_positive_vaSTRING
HIGHonnxruntime/python/tools/transformers/float16.py179Convert tensor float type in the input ONNX model to tensor float16. Args: model (ModelProto or str): The OSTRING
HIGHonnxruntime/python/tools/transformers/profiler.py268Create dummy inputs for GPT-2 model. Args: onnx_model (OnnxModel): ONNX model batch_size (int): batSTRING
HIGHonnxruntime/python/tools/transformers/profiler.py316Create dummy inputs for Longformer model. Args: onnx_model (OnnxModel): ONNX model batch_size (int)STRING
HIGH…ing/python/training/onnxblock/_training_graph_utils.py213Returns trainable and non trainable onnx model parameters. This function pulls out the model parameters from the inSTRING
HIGH…aining/orttraining/python/training/ortmodule/_utils.py165Returns the first device found in the `module`'s parameters or None Args: module (torch.nn.Module): PyTorchSTRING
HIGH…g/orttraining/python/training/utils/torch_io_helper.py127Extract the data schema by replacing every torch.Tensor value with _TensorStub, and return all tensors in a list. STRING
HIGH…g/orttraining/python/training/utils/torch_io_helper.py236Follows the schema to generate an output that is expected by the user. Depth first traversal to iterate over the scSTRING
HIGH…ng/orttraining/python/training/api/checkpoint_state.py76Gets the parameter associated with the given name Searches for the name in the parameters of the checkpoint staSTRING
HIGH…ng/orttraining/python/training/api/checkpoint_state.py144Gets the property associated with the given name Searches for the name in the properties of the checkpoint statSTRING
Cross-Language Confusion16 hits · 78 pts
SeverityFileLineSnippetContext
HIGHtools/ci_build/build.py1261 ["cmd", "/s", "/c", "call .\\emsdk_env && set"],CODE
HIGHtools/ci_build/build.py1268 ["sh", "-c", ". ./emsdk_env.sh && printenv"],CODE
HIGHtools/ci_build/coverage.py52 adb_shell("cd /data/local/tmp && tar -zcf gcda_files.tar.gz *.dir")CODE
HIGHonnxruntime/test/python/onnxruntime_test_python.py670 # The entry my be None (null) but it should be presentCOMMENT
HIGH…st/python/transformers/test_onnx_attention/test_gqa.py2529 (!is_gqa || head_size == v_head_size) clause of the MEA eligibilitySTRING
HIGH…st/python/transformers/test_onnx_attention/test_gqa.py2884 predicate at attention.cc explicitly excludes is_gqa && std::is_same<T,STRING
HIGHonnxruntime/test/common/test_cpuinfo_sysfs_fallback.py178 if (arm_linux_processors_count == (unsigned int)nproc && valid_processors == processors_count) {CODE
HIGHonnxruntime/test/common/test_cpuinfo_sysfs_fallback.py232 return (strcmp(path, CPU_POSSIBLE) == 0 || strcmp(path, CPU_PRESENT) == 0);CODE
HIGHonnxruntime/test/common/test_cpuinfo_sysfs_fallback.py283 if (path && is_blocked(path)) {CODE
HIGHonnxruntime/test/common/test_cpuinfo_sysfs_fallback.py302 if (path && is_blocked(path)) {CODE
HIGHonnxruntime/test/common/test_cpuinfo_sysfs_fallback.py447 return (strcmp(path, CPU_POSSIBLE) == 0 || strcmp(path, CPU_PRESENT) == 0);CODE
HIGHonnxruntime/test/common/test_cpuinfo_sysfs_fallback.py492 if (path && is_blocked(path)) { errno = ENOENT; return -1; }CODE
HIGHonnxruntime/test/common/test_cpuinfo_sysfs_fallback.py508 if (path && is_blocked(path)) { errno = ENOENT; return -1; }CODE
HIGH…ools/transformers/models/whisper/whisper_jump_times.py244 while (i > 0 || j > 0) {CODE
HIGH…ools/transformers/models/whisper/whisper_jump_times.py284 if (c0 < c1 && c0 < c2) {CODE
HIGH…ools/transformers/models/whisper/whisper_jump_times.py287 } else if (c1 < c0 && c1 < c2) {CODE
Structural Annotation Overuse39 hits · 68 pts
SeverityFileLineSnippetContext
LOWtools/python/util/android/android.py249 # Step 1: List running devicesCOMMENT
LOWtools/python/util/android/android.py258 # Step 2: Check each running emulator's AVD nameCOMMENT
LOWonnxruntime/core/framework/copy.h168 // Step 1: if there is anything left in the contiguous span that we are starting in, finish copying itCOMMENT
LOWonnxruntime/core/framework/copy.h183 // Step 2: copy contiguous span by contiguous span until we reach the penultimate spanCOMMENT
LOWonnxruntime/core/framework/copy.h190 // Step 3: finish off the last (possibly partial) span manually, making sure that we don't go past the lastCOMMENT
LOW…ntime/core/providers/qnn/builder/qnn_backend_manager.h169 // NOTE: This function locks the internal `logger_recursive_mutex_`.COMMENT
LOW…ntime/core/providers/qnn/builder/qnn_backend_manager.h209 // NOTE: This function locks the internal `logger_recursive_mutex_`.COMMENT
LOW…ntime/core/providers/qnn/builder/qnn_backend_manager.h328 // NOTE: This function locks the internal `logger_recursive_mutex_`.COMMENT
LOW…ntime/core/providers/qnn/builder/qnn_backend_manager.h332 // NOTE: This function indirectly locks the internal `logger_recursive_mutex_` via nested function calls.COMMENT
LOWonnxruntime/core/mlas/lib/flashattn_qkv.cpp142 // Step 1: QK^T GEMM with quantized K blockCOMMENT
LOWonnxruntime/core/mlas/lib/flashattn_qkv.cpp190 // Step 2: Apply causal mask and Step 3: Online softmax updateCOMMENT
LOWonnxruntime/core/mlas/lib/flashattn_qkv.cpp257 // Step 4: Accumulate O += S_exp * V_block using fused dequant+GEMMCOMMENT
LOWonnxruntime/core/mlas/lib/flashattn_qkv.cpp393 // Step 1: QK^T GEMM for this KV chunkCOMMENT
LOWonnxruntime/core/mlas/lib/flashattn_qkv.cpp433 // Step 2: Apply causal maskCOMMENT
LOWonnxruntime/core/mlas/lib/flashattn_qkv.cpp455 // Step 3: Compute local softmax statistics (m, l) and exp scoresCOMMENT
LOWonnxruntime/core/mlas/lib/flashattn_qkv.cpp487 // Step 4: S_exp * V_block -> partial_outputCOMMENT
LOWonnxruntime/core/mlas/lib/flashattn_gqa.cpp733 // Step 2: local-window masking (no causal mask needed for decode).COMMENT
LOWonnxruntime/core/mlas/lib/flashattn_gqa.cpp740 // Step 3: softmax over scores[0..T).COMMENT
LOWonnxruntime/core/mlas/lib/flashattn_gqa.cpp213 // Step 1: QK^T GEMM with FP32 K blockCOMMENT
LOWonnxruntime/core/mlas/lib/flashattn_gqa.cpp260 // Step 2: Apply causal mask and Step 3: Online softmax updateCOMMENT
LOWonnxruntime/core/mlas/lib/flashattn_gqa.cpp327 // Step 4: Accumulate O += S_exp * V_blockCOMMENT
LOWonnxruntime/core/mlas/lib/flashattn_gqa.cpp452 // Step 1: QK^T GEMV for this KV chunk (M = 1)COMMENT
LOWonnxruntime/core/mlas/lib/flashattn_gqa.cpp479 // Step 2: Apply causal maskCOMMENT
LOWonnxruntime/core/mlas/lib/flashattn_gqa.cpp501 // Step 3: Compute local softmax statistics (m, l) and exp scoresCOMMENT
LOWonnxruntime/core/mlas/lib/flashattn_gqa.cpp533 // Step 4: S_exp * V_block -> partial_output (M = 1)COMMENT
LOWonnxruntime/core/mlas/lib/flashattn_gqa.cpp711 // Step 1: QK^T GEMV -> scores[0..T)COMMENT
LOWonnxruntime/core/mlas/lib/flashattn_gqa.cpp764 // Step 4: S_exp * V GEMV -> temp_output, then normalize by 1/l.COMMENT
LOW…ython/quantization/test_qoperator_adjust_int32_bias.py29 # Step 1: reshape to (C_out, -1) to ensure per-channel broadcastingCOMMENT
LOW…ython/quantization/test_qoperator_adjust_int32_bias.py36 # Step 2: reshape back to original shapeCOMMENT
LOW…est/python/orttraining_test_fused_adam_cpu_fallback.py46# Step 1: load _multi_tensor_apply as a top-level module (no package needed,COMMENT
LOW…est/python/orttraining_test_fused_adam_cpu_fallback.py58# Step 2: load fused_adam.py with __package__ = _PKG so its relative importCOMMENT
LOW…ining/orttraining/python/training/ortmodule/options.py143 # WARNING: The shape inference of com.microsoft::SoftmaxCrossEntropyLossInternal type is missing, soCOMMENT
LOW…ining/orttraining/python/training/ortmodule/options.py144 # WARNING: The shape inference of com.microsoft::PythonOp type is missing, so it may result in wrongCOMMENT
LOW…ining/orttraining/python/training/ortmodule/options.py145 # WARNING: The shape inference of org.pytorch.aten::ATen type is missing, so it may result in wrong COMMENT
LOW…ining/orttraining/python/training/ortmodule/options.py146 # WARNING: The shape inference of prim::Constant type is missing, so it may result in wrong shape inCOMMENT
LOWdocs/ORTModule_ModuleWithLoss_Wrapper.md20### Step 1: Define `ModuleWithLoss` ClassCOMMENT
LOWdocs/ORTModule_ModuleWithLoss_Wrapper.md43### Step 2: Define a sample training scriptCOMMENT
LOW…ing/PartitioningWithAnnotationsAndMemoryConstraints.md223### Step 1: Collect Memory Statistics (Profiling Run)COMMENT
LOW…ing/PartitioningWithAnnotationsAndMemoryConstraints.md274### Step 2: Partition with a Memory BudgetCOMMENT
Verbosity Indicators30 hits · 51 pts
SeverityFileLineSnippetContext
LOWtools/python/util/android/android.py249 # Step 1: List running devicesCOMMENT
LOWtools/python/util/android/android.py258 # Step 2: Check each running emulator's AVD nameCOMMENT
LOWonnxruntime/core/framework/copy.h168 // Step 1: if there is anything left in the contiguous span that we are starting in, finish copying itCOMMENT
LOWonnxruntime/core/framework/copy.h183 // Step 2: copy contiguous span by contiguous span until we reach the penultimate spanCOMMENT
LOWonnxruntime/core/framework/copy.h190 // Step 3: finish off the last (possibly partial) span manually, making sure that we don't go past the lastCOMMENT
LOWonnxruntime/core/mlas/lib/flashattn_qkv.cpp142 // Step 1: QK^T GEMM with quantized K blockCOMMENT
LOWonnxruntime/core/mlas/lib/flashattn_qkv.cpp190 // Step 2: Apply causal mask and Step 3: Online softmax updateCOMMENT
LOWonnxruntime/core/mlas/lib/flashattn_qkv.cpp257 // Step 4: Accumulate O += S_exp * V_block using fused dequant+GEMMCOMMENT
LOWonnxruntime/core/mlas/lib/flashattn_qkv.cpp393 // Step 1: QK^T GEMM for this KV chunkCOMMENT
LOWonnxruntime/core/mlas/lib/flashattn_qkv.cpp433 // Step 2: Apply causal maskCOMMENT
LOWonnxruntime/core/mlas/lib/flashattn_qkv.cpp455 // Step 3: Compute local softmax statistics (m, l) and exp scoresCOMMENT
LOWonnxruntime/core/mlas/lib/flashattn_qkv.cpp487 // Step 4: S_exp * V_block -> partial_outputCOMMENT
LOWonnxruntime/core/mlas/lib/flashattn_gqa.cpp733 // Step 2: local-window masking (no causal mask needed for decode).COMMENT
LOWonnxruntime/core/mlas/lib/flashattn_gqa.cpp740 // Step 3: softmax over scores[0..T).COMMENT
LOWonnxruntime/core/mlas/lib/flashattn_gqa.cpp213 // Step 1: QK^T GEMM with FP32 K blockCOMMENT
LOWonnxruntime/core/mlas/lib/flashattn_gqa.cpp260 // Step 2: Apply causal mask and Step 3: Online softmax updateCOMMENT
LOWonnxruntime/core/mlas/lib/flashattn_gqa.cpp327 // Step 4: Accumulate O += S_exp * V_blockCOMMENT
LOWonnxruntime/core/mlas/lib/flashattn_gqa.cpp452 // Step 1: QK^T GEMV for this KV chunk (M = 1)COMMENT
LOWonnxruntime/core/mlas/lib/flashattn_gqa.cpp479 // Step 2: Apply causal maskCOMMENT
LOWonnxruntime/core/mlas/lib/flashattn_gqa.cpp501 // Step 3: Compute local softmax statistics (m, l) and exp scoresCOMMENT
LOWonnxruntime/core/mlas/lib/flashattn_gqa.cpp533 // Step 4: S_exp * V_block -> partial_output (M = 1)COMMENT
LOWonnxruntime/core/mlas/lib/flashattn_gqa.cpp711 // Step 1: QK^T GEMV -> scores[0..T)COMMENT
LOWonnxruntime/core/mlas/lib/flashattn_gqa.cpp764 // Step 4: S_exp * V GEMV -> temp_output, then normalize by 1/l.COMMENT
LOW…ython/quantization/test_qoperator_adjust_int32_bias.py29 # Step 1: reshape to (C_out, -1) to ensure per-channel broadcastingCOMMENT
LOW…ython/quantization/test_qoperator_adjust_int32_bias.py36 # Step 2: reshape back to original shapeCOMMENT
LOW…est/python/orttraining_test_fused_adam_cpu_fallback.py46# Step 1: load _multi_tensor_apply as a top-level module (no package needed,COMMENT
LOW…est/python/orttraining_test_fused_adam_cpu_fallback.py58# Step 2: load fused_adam.py with __package__ = _PKG so its relative importCOMMENT
LOWinclude/onnxruntime/core/framework/kernel_def_builder.h134 // This variable stores <input_offset, output_offset> for the variadic alias mappingCOMMENT
LOWinclude/onnxruntime/core/graph/node_arg.h148 // This variable stores the actual tensor data of the shape as a TensorShapeProto after executingCOMMENT
LOWinclude/onnxruntime/core/graph/node_arg.h161 // This variable stores the actual scalar value.COMMENT
Dead Code16 hits · 32 pts
SeverityFileLineSnippetContext
MEDIUM…ing/test/python/orttraining_test_ortmodule_onnx_ops.py153CODE
MEDIUM…ing/test/python/orttraining_test_ortmodule_onnx_ops.py157CODE
MEDIUM…ing/test/python/orttraining_test_ortmodule_onnx_ops.py165CODE
MEDIUM…ing/test/python/orttraining_test_ortmodule_onnx_ops.py166CODE
MEDIUM…ing/test/python/orttraining_test_ortmodule_onnx_ops.py168CODE
MEDIUM…ing/test/python/orttraining_test_ortmodule_onnx_ops.py169CODE
MEDIUM…ing/test/python/orttraining_test_ortmodule_onnx_ops.py170CODE
MEDIUM…ing/test/python/orttraining_test_ortmodule_onnx_ops.py171CODE
MEDIUM…ing/test/python/orttraining_test_ortmodule_onnx_ops.py172CODE
MEDIUM…ing/test/python/orttraining_test_ortmodule_onnx_ops.py173CODE
MEDIUM…ing/test/python/orttraining_test_ortmodule_onnx_ops.py175CODE
MEDIUM…ing/test/python/orttraining_test_ortmodule_onnx_ops.py176CODE
MEDIUM…ing/test/python/orttraining_test_ortmodule_onnx_ops.py177CODE
MEDIUM…ing/test/python/orttraining_test_ortmodule_onnx_ops.py178CODE
MEDIUM…ing/test/python/orttraining_test_ortmodule_onnx_ops.py179CODE
MEDIUM…ing/test/python/orttraining_test_ortmodule_onnx_ops.py181CODE
Slop Phrases9 hits · 24 pts
SeverityFileLineSnippetContext
MEDIUMtools/ci_build/github/Doxyfile_csharp.cfg338# Note: For files without extension you can use no_extension as a placeholder.COMMENT
MEDIUMtools/ci_build/github/Doxyfile_csharp.cfg923# If the value of the INPUT tag contains directories, you can use theCOMMENT
MEDIUMtools/ci_build/github/Doxyfile_csharp.cfg965# If the value of the INPUT tag contains directories, you can use theCOMMENT
MEDIUMtools/ci_build/github/Doxyfile_csharp.cfg991# If the value of the EXAMPLE_PATH tag contains directories, you can use theCOMMENT
LOWonnxruntime/test/python/transformers/test_moe_cuda.py945 # the current expert. We need to make sure to multiply the output hiddenCOMMENT
LOWonnxruntime/test/python/transformers/test_moe_cuda.py1132 # the current expert. We need to make sure to multiply the output hiddenCOMMENT
MEDIUMonnxruntime/python/tools/transformers/optimizer.py18# (3) Some model cannot be handled by OnnxRuntime, and you can modify this script to get optimized model.COMMENT
MEDIUM…ools/transformers/models/t5/t5_encoder_decoder_init.py218 # Workaround as mentioned earlier: change numeric dim_param to dim_valueCOMMENT
MEDIUM…ools/transformers/models/longformer/convert_to_onnx.py30# GPU is not needed for this script. You can run it in CPU. For --optimize_onnx, you can use either onnxruntime or onnxrCOMMENT
TODO Padding10 hits · 15 pts
SeverityFileLineSnippetContext
LOW…utionProvider/src/External/DirectMLHelpers/DirectMLX.h2000 // TODO: implement meCOMMENT
LOWonnxruntime/test/perftest/test_session.h21 // TODO: implement itCOMMENT
LOWonnxruntime/test/perftest/ort_test_session.h66 // TODO: implement a customized allocator, then we can remove output_names_ to simplify this codeCOMMENT
LOWjs/web/lib/wasm/session-handler-inference.ts148 // TODO: implement profilingCOMMENT
LOWjs/web/lib/wasm/jsep/webgpu/ops/conv.ts315 // TODO: implement conv2dWithIm2Col()COMMENT
LOWjs/web/lib/wasm/jsep/webgpu/ops/binary-op.ts288 // TODO: implement vectorized powCOMMENT
LOW…ning/training_ops/cuda/loss/softmaxcrossentropy_impl.h71 // TODO: implement reduction type of NONECOMMENT
LOW…ning/training_ops/cuda/loss/softmaxcrossentropy_impl.h82 // TODO: implement reduction type of NONECOMMENT
LOW…ning/training_ops/cuda/loss/softmaxcrossentropy_impl.h93 // TODO: implement reduction type of NONECOMMENT
LOW…ning/training_ops/cuda/loss/softmaxcrossentropy_impl.h104 // TODO: implement reduction type of NONECOMMENT
Example Usage Blocks8 hits · 14 pts
SeverityFileLineSnippetContext
LOW…ime/test/python/transformers/run_disable_sync_check.sh22# Usage:COMMENT
LOW…xruntime/test/python/transformers/profile_qmoe_gemv.sh9# Usage:COMMENT
LOWonnxruntime/test/python/transformers/profile_gqa.sh9# Usage:COMMENT
LOW…me/test/python/transformers/profile_skip_layer_norm.sh9# Usage:COMMENT
LOWjs/build_webgpu.sh7# Usage:COMMENT
LOWorttraining/tools/scripts/opset12_model_transform.py10# Example usage:COMMENT
LOW…soft.ML.OnnxRuntime/Training/TrainingSession.shared.cs294 /// Example usage:COMMENT
LOW…soft.ML.OnnxRuntime/Training/TrainingSession.shared.cs419 /// Example usage:COMMENT
AI Response Leakage1 hit · 8 pts
SeverityFileLineSnippetContext
HIGHonnxruntime/test/ep_weight_sharing_ctx_gen/README.md75 # In this example, we pick the first one.COMMENT
Fake / Example Data4 hits · 5 pts
SeverityFileLineSnippetContext
LOW…e/test/autoep/library/example_plugin_ep/ep_custom_op.h18// 2. A "placeholder" OrtCustomOp with an empty kernel implementationCOMMENT
LOWinclude/onnxruntime/core/session/onnxruntime_ep_c_api.h2972 * 2. A "placeholder" OrtCustomOp with an empty kernel implementationCOMMENT
LOWjava/src/test/java/ai/onnxruntime/InferenceTest.java1595 Assertions.assertEquals("dummy_value", modelMetadata.getCustomMetadata().get("dummy_key"));CODE
LOW…Microsoft.ML.OnnxRuntime.Tests.Common/InferenceTest.cs1662 Assert.Equal("dummy_value", modelMetadata.CustomMetadataMap["dummy_key"]);CODE